# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_STC_AUTOCOMP_CANCELLED = object
EVT_STC_AUTOCOMP_CHAR_DELETED = object
EVT_STC_AUTOCOMP_SELECTION = object
EVT_STC_CALLTIP_CLICK = object
EVT_STC_CHANGE = object
EVT_STC_CHARADDED = object
EVT_STC_DOUBLECLICK = object
EVT_STC_DO_DROP = object
EVT_STC_DRAG_OVER = object
EVT_STC_DWELLEND = object
EVT_STC_DWELLSTART = object
EVT_STC_HOTSPOT_CLICK = object
EVT_STC_HOTSPOT_DCLICK = object
EVT_STC_HOTSPOT_RELEASE_CLICK = object
EVT_STC_INDICATOR_CLICK = object
EVT_STC_INDICATOR_RELEASE = object
EVT_STC_KEY = object
EVT_STC_MACRORECORD = object
EVT_STC_MARGINCLICK = object
EVT_STC_MODIFIED = object
EVT_STC_NEEDSHOWN = object
EVT_STC_PAINTED = object
EVT_STC_ROMODIFYATTEMPT = object
EVT_STC_SAVEPOINTLEFT = object
EVT_STC_SAVEPOINTREACHED = object
EVT_STC_START_DRAG = object
EVT_STC_STYLENEEDED = object
EVT_STC_UPDATEUI = object
EVT_STC_URIDROPPED = object
EVT_STC_USERLISTSELECTION = object
EVT_STC_ZOOM = object
ID_ANY = object
STCNameStr = bytes()
STC_4GL_BLOCK = 0
STC_4GL_BLOCK_ = 0
STC_4GL_CHARACTER = 0
STC_4GL_CHARACTER_ = 0
STC_4GL_COMMENT1 = 0
STC_4GL_COMMENT1_ = 0
STC_4GL_COMMENT2 = 0
STC_4GL_COMMENT2_ = 0
STC_4GL_COMMENT3 = 0
STC_4GL_COMMENT3_ = 0
STC_4GL_COMMENT4 = 0
STC_4GL_COMMENT4_ = 0
STC_4GL_COMMENT5 = 0
STC_4GL_COMMENT5_ = 0
STC_4GL_COMMENT6 = 0
STC_4GL_COMMENT6_ = 0
STC_4GL_DEFAULT = 0
STC_4GL_DEFAULT_ = 0
STC_4GL_END = 0
STC_4GL_END_ = 0
STC_4GL_IDENTIFIER = 0
STC_4GL_IDENTIFIER_ = 0
STC_4GL_NUMBER = 0
STC_4GL_NUMBER_ = 0
STC_4GL_OPERATOR = 0
STC_4GL_OPERATOR_ = 0
STC_4GL_PREPROCESSOR = 0
STC_4GL_PREPROCESSOR_ = 0
STC_4GL_STRING = 0
STC_4GL_STRING_ = 0
STC_4GL_WORD = 0
STC_4GL_WORD_ = 0
STC_A68K_COMMENT = 0
STC_A68K_COMMENT_DOXYGEN = 0
STC_A68K_COMMENT_SPECIAL = 0
STC_A68K_COMMENT_WORD = 0
STC_A68K_CPUINSTRUCTION = 0
STC_A68K_DEFAULT = 0
STC_A68K_DIRECTIVE = 0
STC_A68K_EXTINSTRUCTION = 0
STC_A68K_IDENTIFIER = 0
STC_A68K_LABEL = 0
STC_A68K_MACRO_ARG = 0
STC_A68K_MACRO_DECLARATION = 0
STC_A68K_NUMBER_BIN = 0
STC_A68K_NUMBER_DEC = 0
STC_A68K_NUMBER_HEX = 0
STC_A68K_OPERATOR = 0
STC_A68K_REGISTER = 0
STC_A68K_STRING1 = 0
STC_A68K_STRING2 = 0
STC_ABAQUS_ARGUMENT = 0
STC_ABAQUS_COMMAND = 0
STC_ABAQUS_COMMENT = 0
STC_ABAQUS_COMMENTBLOCK = 0
STC_ABAQUS_DEFAULT = 0
STC_ABAQUS_FUNCTION = 0
STC_ABAQUS_NUMBER = 0
STC_ABAQUS_OPERATOR = 0
STC_ABAQUS_PROCESSOR = 0
STC_ABAQUS_SLASHCOMMAND = 0
STC_ABAQUS_STARCOMMAND = 0
STC_ABAQUS_STRING = 0
STC_ABAQUS_WORD = 0
STC_ADA_CHARACTER = 0
STC_ADA_CHARACTEREOL = 0
STC_ADA_COMMENTLINE = 0
STC_ADA_DEFAULT = 0
STC_ADA_DELIMITER = 0
STC_ADA_IDENTIFIER = 0
STC_ADA_ILLEGAL = 0
STC_ADA_LABEL = 0
STC_ADA_NUMBER = 0
STC_ADA_STRING = 0
STC_ADA_STRINGEOL = 0
STC_ADA_WORD = 0
STC_ALPHA_NOALPHA = 0
STC_ALPHA_OPAQUE = 0
STC_ALPHA_TRANSPARENT = 0
STC_ANNOTATION_BOXED = 0
STC_ANNOTATION_HIDDEN = 0
STC_ANNOTATION_STANDARD = 0
STC_APDL_ARGUMENT = 0
STC_APDL_COMMAND = 0
STC_APDL_COMMENT = 0
STC_APDL_COMMENTBLOCK = 0
STC_APDL_DEFAULT = 0
STC_APDL_FUNCTION = 0
STC_APDL_NUMBER = 0
STC_APDL_OPERATOR = 0
STC_APDL_PROCESSOR = 0
STC_APDL_SLASHCOMMAND = 0
STC_APDL_STARCOMMAND = 0
STC_APDL_STRING = 0
STC_APDL_WORD = 0
STC_ASM_CHARACTER = 0
STC_ASM_COMMENT = 0
STC_ASM_COMMENTBLOCK = 0
STC_ASM_COMMENTDIRECTIVE = 0
STC_ASM_CPUINSTRUCTION = 0
STC_ASM_DEFAULT = 0
STC_ASM_DIRECTIVE = 0
STC_ASM_DIRECTIVEOPERAND = 0
STC_ASM_EXTINSTRUCTION = 0
STC_ASM_IDENTIFIER = 0
STC_ASM_MATHINSTRUCTION = 0
STC_ASM_NUMBER = 0
STC_ASM_OPERATOR = 0
STC_ASM_REGISTER = 0
STC_ASM_STRING = 0
STC_ASM_STRINGEOL = 0
STC_ASN1_ATTRIBUTE = 0
STC_ASN1_COMMENT = 0
STC_ASN1_DEFAULT = 0
STC_ASN1_DESCRIPTOR = 0
STC_ASN1_IDENTIFIER = 0
STC_ASN1_KEYWORD = 0
STC_ASN1_OID = 0
STC_ASN1_OPERATOR = 0
STC_ASN1_SCALAR = 0
STC_ASN1_STRING = 0
STC_ASN1_TYPE = 0
STC_ASY_CHARACTER = 0
STC_ASY_COMMENT = 0
STC_ASY_COMMENTLINE = 0
STC_ASY_COMMENTLINEDOC = 0
STC_ASY_DEFAULT = 0
STC_ASY_IDENTIFIER = 0
STC_ASY_NUMBER = 0
STC_ASY_OPERATOR = 0
STC_ASY_STRING = 0
STC_ASY_STRINGEOL = 0
STC_ASY_WORD = 0
STC_ASY_WORD2 = 0
STC_AU3_COMMENT = 0
STC_AU3_COMMENTBLOCK = 0
STC_AU3_COMOBJ = 0
STC_AU3_DEFAULT = 0
STC_AU3_EXPAND = 0
STC_AU3_FUNCTION = 0
STC_AU3_KEYWORD = 0
STC_AU3_MACRO = 0
STC_AU3_NUMBER = 0
STC_AU3_OPERATOR = 0
STC_AU3_PREPROCESSOR = 0
STC_AU3_SENT = 0
STC_AU3_SPECIAL = 0
STC_AU3_STRING = 0
STC_AU3_UDF = 0
STC_AU3_VARIABLE = 0
STC_AVE_COMMENT = 0
STC_AVE_DEFAULT = 0
STC_AVE_ENUM = 0
STC_AVE_IDENTIFIER = 0
STC_AVE_NUMBER = 0
STC_AVE_OPERATOR = 0
STC_AVE_STRING = 0
STC_AVE_STRINGEOL = 0
STC_AVE_WORD = 0
STC_AVE_WORD1 = 0
STC_AVE_WORD2 = 0
STC_AVE_WORD3 = 0
STC_AVE_WORD4 = 0
STC_AVE_WORD5 = 0
STC_AVE_WORD6 = 0
STC_AVS_CLIPPROP = 0
STC_AVS_COMMENTBLOCK = 0
STC_AVS_COMMENTBLOCKN = 0
STC_AVS_COMMENTLINE = 0
STC_AVS_DEFAULT = 0
STC_AVS_FILTER = 0
STC_AVS_FUNCTION = 0
STC_AVS_IDENTIFIER = 0
STC_AVS_KEYWORD = 0
STC_AVS_NUMBER = 0
STC_AVS_OPERATOR = 0
STC_AVS_PLUGIN = 0
STC_AVS_STRING = 0
STC_AVS_TRIPLESTRING = 0
STC_AVS_USERDFN = 0
STC_BAAN_COMMENT = 0
STC_BAAN_COMMENTDOC = 0
STC_BAAN_DEFAULT = 0
STC_BAAN_IDENTIFIER = 0
STC_BAAN_NUMBER = 0
STC_BAAN_OPERATOR = 0
STC_BAAN_PREPROCESSOR = 0
STC_BAAN_STRING = 0
STC_BAAN_STRINGEOL = 0
STC_BAAN_WORD = 0
STC_BAAN_WORD2 = 0
STC_BAT_COMMAND = 0
STC_BAT_COMMENT = 0
STC_BAT_DEFAULT = 0
STC_BAT_HIDE = 0
STC_BAT_IDENTIFIER = 0
STC_BAT_LABEL = 0
STC_BAT_OPERATOR = 0
STC_BAT_WORD = 0
STC_B_ASM = 0
STC_B_BINNUMBER = 0
STC_B_COMMENT = 0
STC_B_CONSTANT = 0
STC_B_DATE = 0
STC_B_DEFAULT = 0
STC_B_ERROR = 0
STC_B_HEXNUMBER = 0
STC_B_IDENTIFIER = 0
STC_B_KEYWORD = 0
STC_B_KEYWORD2 = 0
STC_B_KEYWORD3 = 0
STC_B_KEYWORD4 = 0
STC_B_LABEL = 0
STC_B_NUMBER = 0
STC_B_OPERATOR = 0
STC_B_PREPROCESSOR = 0
STC_B_STRING = 0
STC_B_STRINGEOL = 0
STC_CACHE_CARET = 0
STC_CACHE_DOCUMENT = 0
STC_CACHE_NONE = 0
STC_CACHE_PAGE = 0
STC_CAML_CHAR = 0
STC_CAML_COMMENT = 0
STC_CAML_COMMENT1 = 0
STC_CAML_COMMENT2 = 0
STC_CAML_COMMENT3 = 0
STC_CAML_DEFAULT = 0
STC_CAML_IDENTIFIER = 0
STC_CAML_KEYWORD = 0
STC_CAML_KEYWORD2 = 0
STC_CAML_KEYWORD3 = 0
STC_CAML_LINENUM = 0
STC_CAML_NUMBER = 0
STC_CAML_OPERATOR = 0
STC_CAML_STRING = 0
STC_CAML_TAGNAME = 0
STC_CAML_WHITE = 0
STC_CARETSTICKY_OFF = 0
STC_CARETSTICKY_ON = 0
STC_CARETSTICKY_WHITESPACE = 0
STC_CARETSTYLE_BLOCK = 0
STC_CARETSTYLE_INVISIBLE = 0
STC_CARETSTYLE_LINE = 0
STC_CARET_EVEN = 0
STC_CARET_JUMPS = 0
STC_CARET_SLOP = 0
STC_CARET_STRICT = 0
STC_CASEINSENSITIVEBEHAVIOUR_IGNORECASE = 0
STC_CASEINSENSITIVEBEHAVIOUR_RESPECTCASE = 0
STC_CASE_LOWER = 0
STC_CASE_MIXED = 0
STC_CASE_UPPER = 0
STC_CHARSET_8859_15 = 0
STC_CHARSET_ANSI = 0
STC_CHARSET_ARABIC = 0
STC_CHARSET_BALTIC = 0
STC_CHARSET_CHINESEBIG5 = 0
STC_CHARSET_CYRILLIC = 0
STC_CHARSET_DEFAULT = 0
STC_CHARSET_EASTEUROPE = 0
STC_CHARSET_GB2312 = 0
STC_CHARSET_GREEK = 0
STC_CHARSET_HANGUL = 0
STC_CHARSET_HEBREW = 0
STC_CHARSET_JOHAB = 0
STC_CHARSET_MAC = 0
STC_CHARSET_OEM = 0
STC_CHARSET_RUSSIAN = 0
STC_CHARSET_SHIFTJIS = 0
STC_CHARSET_SYMBOL = 0
STC_CHARSET_THAI = 0
STC_CHARSET_TURKISH = 0
STC_CHARSET_VIETNAMESE = 0
STC_CLW_ATTRIBUTE = 0
STC_CLW_BUILTIN_PROCEDURES_FUNCTION = 0
STC_CLW_COMMENT = 0
STC_CLW_COMPILER_DIRECTIVE = 0
STC_CLW_DEFAULT = 0
STC_CLW_DEPRECATED = 0
STC_CLW_ERROR = 0
STC_CLW_INTEGER_CONSTANT = 0
STC_CLW_KEYWORD = 0
STC_CLW_LABEL = 0
STC_CLW_PICTURE_STRING = 0
STC_CLW_REAL_CONSTANT = 0
STC_CLW_RUNTIME_EXPRESSIONS = 0
STC_CLW_STANDARD_EQUATE = 0
STC_CLW_STRING = 0
STC_CLW_STRUCTURE_DATA_TYPE = 0
STC_CLW_USER_IDENTIFIER = 0
STC_CMAKE_COMMANDS = 0
STC_CMAKE_COMMENT = 0
STC_CMAKE_DEFAULT = 0
STC_CMAKE_FOREACHDEF = 0
STC_CMAKE_IFDEFINEDEF = 0
STC_CMAKE_MACRODEF = 0
STC_CMAKE_NUMBER = 0
STC_CMAKE_PARAMETERS = 0
STC_CMAKE_STRINGDQ = 0
STC_CMAKE_STRINGLQ = 0
STC_CMAKE_STRINGRQ = 0
STC_CMAKE_STRINGVAR = 0
STC_CMAKE_USERDEFINED = 0
STC_CMAKE_VARIABLE = 0
STC_CMAKE_WHILEDEF = 0
STC_CMD_BACKTAB = 0
STC_CMD_CANCEL = 0
STC_CMD_CHARLEFT = 0
STC_CMD_CHARLEFTEXTEND = 0
STC_CMD_CHARLEFTRECTEXTEND = 0
STC_CMD_CHARRIGHT = 0
STC_CMD_CHARRIGHTEXTEND = 0
STC_CMD_CHARRIGHTRECTEXTEND = 0
STC_CMD_CLEAR = 0
STC_CMD_COPY = 0
STC_CMD_CUT = 0
STC_CMD_DELETEBACK = 0
STC_CMD_DELETEBACKNOTLINE = 0
STC_CMD_DELLINELEFT = 0
STC_CMD_DELLINERIGHT = 0
STC_CMD_DELWORDLEFT = 0
STC_CMD_DELWORDRIGHT = 0
STC_CMD_DELWORDRIGHTEND = 0
STC_CMD_DOCUMENTEND = 0
STC_CMD_DOCUMENTENDEXTEND = 0
STC_CMD_DOCUMENTSTART = 0
STC_CMD_DOCUMENTSTARTEXTEND = 0
STC_CMD_EDITTOGGLEOVERTYPE = 0
STC_CMD_FORMFEED = 0
STC_CMD_HOME = 0
STC_CMD_HOMEDISPLAY = 0
STC_CMD_HOMEDISPLAYEXTEND = 0
STC_CMD_HOMEEXTEND = 0
STC_CMD_HOMERECTEXTEND = 0
STC_CMD_HOMEWRAP = 0
STC_CMD_HOMEWRAPEXTEND = 0
STC_CMD_LINECOPY = 0
STC_CMD_LINECUT = 0
STC_CMD_LINEDELETE = 0
STC_CMD_LINEDOWN = 0
STC_CMD_LINEDOWNEXTEND = 0
STC_CMD_LINEDOWNRECTEXTEND = 0
STC_CMD_LINEDUPLICATE = 0
STC_CMD_LINEEND = 0
STC_CMD_LINEENDDISPLAY = 0
STC_CMD_LINEENDDISPLAYEXTEND = 0
STC_CMD_LINEENDEXTEND = 0
STC_CMD_LINEENDRECTEXTEND = 0
STC_CMD_LINEENDWRAP = 0
STC_CMD_LINEENDWRAPEXTEND = 0
STC_CMD_LINESCROLLDOWN = 0
STC_CMD_LINESCROLLUP = 0
STC_CMD_LINETRANSPOSE = 0
STC_CMD_LINEUP = 0
STC_CMD_LINEUPEXTEND = 0
STC_CMD_LINEUPRECTEXTEND = 0
STC_CMD_LOWERCASE = 0
STC_CMD_MOVESELECTEDLINESDOWN = 0
STC_CMD_MOVESELECTEDLINESUP = 0
STC_CMD_NEWLINE = 0
STC_CMD_PAGEDOWN = 0
STC_CMD_PAGEDOWNEXTEND = 0
STC_CMD_PAGEDOWNRECTEXTEND = 0
STC_CMD_PAGEUP = 0
STC_CMD_PAGEUPEXTEND = 0
STC_CMD_PAGEUPRECTEXTEND = 0
STC_CMD_PARADOWN = 0
STC_CMD_PARADOWNEXTEND = 0
STC_CMD_PARAUP = 0
STC_CMD_PARAUPEXTEND = 0
STC_CMD_PASTE = 0
STC_CMD_REDO = 0
STC_CMD_SCROLLTOEND = 0
STC_CMD_SCROLLTOSTART = 0
STC_CMD_SELECTALL = 0
STC_CMD_STUTTEREDPAGEDOWN = 0
STC_CMD_STUTTEREDPAGEDOWNEXTEND = 0
STC_CMD_STUTTEREDPAGEUP = 0
STC_CMD_STUTTEREDPAGEUPEXTEND = 0
STC_CMD_TAB = 0
STC_CMD_UNDO = 0
STC_CMD_UPPERCASE = 0
STC_CMD_VCHOME = 0
STC_CMD_VCHOMEEXTEND = 0
STC_CMD_VCHOMERECTEXTEND = 0
STC_CMD_VCHOMEWRAP = 0
STC_CMD_VCHOMEWRAPEXTEND = 0
STC_CMD_VERTICALCENTRECARET = 0
STC_CMD_WORDLEFT = 0
STC_CMD_WORDLEFTEND = 0
STC_CMD_WORDLEFTENDEXTEND = 0
STC_CMD_WORDLEFTEXTEND = 0
STC_CMD_WORDPARTLEFT = 0
STC_CMD_WORDPARTLEFTEXTEND = 0
STC_CMD_WORDPARTRIGHT = 0
STC_CMD_WORDPARTRIGHTEXTEND = 0
STC_CMD_WORDRIGHT = 0
STC_CMD_WORDRIGHTEND = 0
STC_CMD_WORDRIGHTENDEXTEND = 0
STC_CMD_WORDRIGHTEXTEND = 0
STC_CMD_ZOOMIN = 0
STC_CMD_ZOOMOUT = 0
STC_COFFEESCRIPT_CHARACTER = 0
STC_COFFEESCRIPT_COMMENT = 0
STC_COFFEESCRIPT_COMMENTBLOCK = 0
STC_COFFEESCRIPT_COMMENTDOC = 0
STC_COFFEESCRIPT_COMMENTDOCKEYWORD = 0
STC_COFFEESCRIPT_COMMENTDOCKEYWORDERROR = 0
STC_COFFEESCRIPT_COMMENTLINE = 0
STC_COFFEESCRIPT_COMMENTLINEDOC = 0
STC_COFFEESCRIPT_DEFAULT = 0
STC_COFFEESCRIPT_GLOBALCLASS = 0
STC_COFFEESCRIPT_HASHQUOTEDSTRING = 0
STC_COFFEESCRIPT_IDENTIFIER = 0
STC_COFFEESCRIPT_NUMBER = 0
STC_COFFEESCRIPT_OPERATOR = 0
STC_COFFEESCRIPT_PREPROCESSOR = 0
STC_COFFEESCRIPT_REGEX = 0
STC_COFFEESCRIPT_STRING = 0
STC_COFFEESCRIPT_STRINGEOL = 0
STC_COFFEESCRIPT_STRINGRAW = 0
STC_COFFEESCRIPT_TRIPLEVERBATIM = 0
STC_COFFEESCRIPT_UUID = 0
STC_COFFEESCRIPT_VERBATIM = 0
STC_COFFEESCRIPT_VERBOSE_REGEX = 0
STC_COFFEESCRIPT_VERBOSE_REGEX_COMMENT = 0
STC_COFFEESCRIPT_WORD = 0
STC_COFFEESCRIPT_WORD2 = 0
STC_CONF_COMMENT = 0
STC_CONF_DEFAULT = 0
STC_CONF_DIRECTIVE = 0
STC_CONF_EXTENSION = 0
STC_CONF_IDENTIFIER = 0
STC_CONF_IP = 0
STC_CONF_NUMBER = 0
STC_CONF_OPERATOR = 0
STC_CONF_PARAMETER = 0
STC_CONF_STRING = 0
STC_CP_UTF8 = 0
STC_CSOUND_ARATE_VAR = 0
STC_CSOUND_COMMENT = 0
STC_CSOUND_COMMENTBLOCK = 0
STC_CSOUND_DEFAULT = 0
STC_CSOUND_GLOBAL_VAR = 0
STC_CSOUND_HEADERSTMT = 0
STC_CSOUND_IDENTIFIER = 0
STC_CSOUND_INSTR = 0
STC_CSOUND_IRATE_VAR = 0
STC_CSOUND_KRATE_VAR = 0
STC_CSOUND_NUMBER = 0
STC_CSOUND_OPCODE = 0
STC_CSOUND_OPERATOR = 0
STC_CSOUND_PARAM = 0
STC_CSOUND_STRINGEOL = 0
STC_CSOUND_USERKEYWORD = 0
STC_CSS_ATTRIBUTE = 0
STC_CSS_CLASS = 0
STC_CSS_COMMENT = 0
STC_CSS_DEFAULT = 0
STC_CSS_DIRECTIVE = 0
STC_CSS_DOUBLESTRING = 0
STC_CSS_EXTENDED_IDENTIFIER = 0
STC_CSS_EXTENDED_PSEUDOCLASS = 0
STC_CSS_EXTENDED_PSEUDOELEMENT = 0
STC_CSS_ID = 0
STC_CSS_IDENTIFIER = 0
STC_CSS_IDENTIFIER2 = 0
STC_CSS_IDENTIFIER3 = 0
STC_CSS_IMPORTANT = 0
STC_CSS_MEDIA = 0
STC_CSS_OPERATOR = 0
STC_CSS_PSEUDOCLASS = 0
STC_CSS_PSEUDOELEMENT = 0
STC_CSS_SINGLESTRING = 0
STC_CSS_TAG = 0
STC_CSS_UNKNOWN_IDENTIFIER = 0
STC_CSS_UNKNOWN_PSEUDOCLASS = 0
STC_CSS_VALUE = 0
STC_CSS_VARIABLE = 0
STC_CURSORARROW = 0
STC_CURSORNORMAL = 0
STC_CURSORREVERSEARROW = 0
STC_CURSORWAIT = 0
STC_C_CHARACTER = 0
STC_C_COMMENT = 0
STC_C_COMMENTDOC = 0
STC_C_COMMENTDOCKEYWORD = 0
STC_C_COMMENTDOCKEYWORDERROR = 0
STC_C_COMMENTLINE = 0
STC_C_COMMENTLINEDOC = 0
STC_C_DEFAULT = 0
STC_C_GLOBALCLASS = 0
STC_C_HASHQUOTEDSTRING = 0
STC_C_IDENTIFIER = 0
STC_C_NUMBER = 0
STC_C_OPERATOR = 0
STC_C_PREPROCESSOR = 0
STC_C_PREPROCESSORCOMMENT = 0
STC_C_REGEX = 0
STC_C_STRING = 0
STC_C_STRINGEOL = 0
STC_C_STRINGRAW = 0
STC_C_TRIPLEVERBATIM = 0
STC_C_UUID = 0
STC_C_VERBATIM = 0
STC_C_WORD = 0
STC_C_WORD2 = 0
STC_DIFF_ADDED = 0
STC_DIFF_CHANGED = 0
STC_DIFF_COMMAND = 0
STC_DIFF_COMMENT = 0
STC_DIFF_DEFAULT = 0
STC_DIFF_DELETED = 0
STC_DIFF_HEADER = 0
STC_DIFF_POSITION = 0
STC_D_CHARACTER = 0
STC_D_COMMENT = 0
STC_D_COMMENTDOC = 0
STC_D_COMMENTDOCKEYWORD = 0
STC_D_COMMENTDOCKEYWORDERROR = 0
STC_D_COMMENTLINE = 0
STC_D_COMMENTLINEDOC = 0
STC_D_COMMENTNESTED = 0
STC_D_DEFAULT = 0
STC_D_IDENTIFIER = 0
STC_D_NUMBER = 0
STC_D_OPERATOR = 0
STC_D_STRING = 0
STC_D_STRINGB = 0
STC_D_STRINGEOL = 0
STC_D_STRINGR = 0
STC_D_TYPEDEF = 0
STC_D_WORD = 0
STC_D_WORD2 = 0
STC_D_WORD3 = 0
STC_D_WORD5 = 0
STC_D_WORD6 = 0
STC_D_WORD7 = 0
STC_ECL_ADDED = 0
STC_ECL_CHANGED = 0
STC_ECL_CHARACTER = 0
STC_ECL_COMMENT = 0
STC_ECL_COMMENTDOC = 0
STC_ECL_COMMENTDOCKEYWORD = 0
STC_ECL_COMMENTDOCKEYWORDERROR = 0
STC_ECL_COMMENTLINE = 0
STC_ECL_COMMENTLINEDOC = 0
STC_ECL_DEFAULT = 0
STC_ECL_DELETED = 0
STC_ECL_IDENTIFIER = 0
STC_ECL_MOVED = 0
STC_ECL_NUMBER = 0
STC_ECL_OPERATOR = 0
STC_ECL_PREPROCESSOR = 0
STC_ECL_REGEX = 0
STC_ECL_STRING = 0
STC_ECL_STRINGEOL = 0
STC_ECL_UNKNOWN = 0
STC_ECL_UUID = 0
STC_ECL_VERBATIM = 0
STC_ECL_WORD0 = 0
STC_ECL_WORD1 = 0
STC_ECL_WORD2 = 0
STC_ECL_WORD3 = 0
STC_ECL_WORD4 = 0
STC_ECL_WORD5 = 0
STC_EDGE_BACKGROUND = 0
STC_EDGE_LINE = 0
STC_EDGE_NONE = 0
STC_EFF_QUALITY_ANTIALIASED = 0
STC_EFF_QUALITY_DEFAULT = 0
STC_EFF_QUALITY_LCD_OPTIMIZED = 0
STC_EFF_QUALITY_MASK = 0
STC_EFF_QUALITY_NON_ANTIALIASED = 0
STC_EIFFEL_CHARACTER = 0
STC_EIFFEL_COMMENTLINE = 0
STC_EIFFEL_DEFAULT = 0
STC_EIFFEL_IDENTIFIER = 0
STC_EIFFEL_NUMBER = 0
STC_EIFFEL_OPERATOR = 0
STC_EIFFEL_STRING = 0
STC_EIFFEL_STRINGEOL = 0
STC_EIFFEL_WORD = 0
STC_EOL_CR = 0
STC_EOL_CRLF = 0
STC_EOL_LF = 0
STC_ERLANG_ATOM = 0
STC_ERLANG_ATOM_QUOTED = 0
STC_ERLANG_BIFS = 0
STC_ERLANG_CHARACTER = 0
STC_ERLANG_COMMENT = 0
STC_ERLANG_COMMENT_DOC = 0
STC_ERLANG_COMMENT_DOC_MACRO = 0
STC_ERLANG_COMMENT_FUNCTION = 0
STC_ERLANG_COMMENT_MODULE = 0
STC_ERLANG_DEFAULT = 0
STC_ERLANG_FUNCTION_NAME = 0
STC_ERLANG_KEYWORD = 0
STC_ERLANG_MACRO = 0
STC_ERLANG_MACRO_QUOTED = 0
STC_ERLANG_MODULES = 0
STC_ERLANG_MODULES_ATT = 0
STC_ERLANG_NODE_NAME = 0
STC_ERLANG_NODE_NAME_QUOTED = 0
STC_ERLANG_NUMBER = 0
STC_ERLANG_OPERATOR = 0
STC_ERLANG_PREPROC = 0
STC_ERLANG_RECORD = 0
STC_ERLANG_RECORD_QUOTED = 0
STC_ERLANG_STRING = 0
STC_ERLANG_UNKNOWN = 0
STC_ERLANG_VARIABLE = 0
STC_ERR_ABSF = 0
STC_ERR_BORLAND = 0
STC_ERR_CMD = 0
STC_ERR_CTAG = 0
STC_ERR_DEFAULT = 0
STC_ERR_DIFF_ADDITION = 0
STC_ERR_DIFF_CHANGED = 0
STC_ERR_DIFF_DELETION = 0
STC_ERR_DIFF_MESSAGE = 0
STC_ERR_ELF = 0
STC_ERR_GCC = 0
STC_ERR_IFC = 0
STC_ERR_IFORT = 0
STC_ERR_JAVA_STACK = 0
STC_ERR_LUA = 0
STC_ERR_MS = 0
STC_ERR_NET = 0
STC_ERR_PERL = 0
STC_ERR_PHP = 0
STC_ERR_PYTHON = 0
STC_ERR_TIDY = 0
STC_ERR_VALUE = 0
STC_ESCRIPT_BRACE = 0
STC_ESCRIPT_COMMENT = 0
STC_ESCRIPT_COMMENTDOC = 0
STC_ESCRIPT_COMMENTLINE = 0
STC_ESCRIPT_DEFAULT = 0
STC_ESCRIPT_IDENTIFIER = 0
STC_ESCRIPT_NUMBER = 0
STC_ESCRIPT_OPERATOR = 0
STC_ESCRIPT_STRING = 0
STC_ESCRIPT_WORD = 0
STC_ESCRIPT_WORD2 = 0
STC_ESCRIPT_WORD3 = 0
STC_FIND_MATCHCASE = 0
STC_FIND_POSIX = 0
STC_FIND_REGEXP = 0
STC_FIND_WHOLEWORD = 0
STC_FIND_WORDSTART = 0
STC_FOLDFLAG_LEVELNUMBERS = 0
STC_FOLDFLAG_LINEAFTER_CONTRACTED = 0
STC_FOLDFLAG_LINEAFTER_EXPANDED = 0
STC_FOLDFLAG_LINEBEFORE_CONTRACTED = 0
STC_FOLDFLAG_LINEBEFORE_EXPANDED = 0
STC_FOLDLEVELBASE = 0
STC_FOLDLEVELHEADERFLAG = 0
STC_FOLDLEVELNUMBERMASK = 0
STC_FOLDLEVELWHITEFLAG = 0
STC_FONT_SIZE_MULTIPLIER = 0
STC_FORTH_COMMENT = 0
STC_FORTH_COMMENT_ML = 0
STC_FORTH_CONTROL = 0
STC_FORTH_DEFAULT = 0
STC_FORTH_DEFWORD = 0
STC_FORTH_IDENTIFIER = 0
STC_FORTH_KEYWORD = 0
STC_FORTH_LOCALE = 0
STC_FORTH_NUMBER = 0
STC_FORTH_PREWORD1 = 0
STC_FORTH_PREWORD2 = 0
STC_FORTH_STRING = 0
STC_FS_COMMENT = 0
STC_FS_COMMENTDOC = 0
STC_FS_COMMENTDOCKEYWORD = 0
STC_FS_COMMENTDOCKEYWORDERROR = 0
STC_FS_COMMENTDOC_C = 0
STC_FS_COMMENTLINE = 0
STC_FS_COMMENTLINEDOC = 0
STC_FS_COMMENTLINEDOC_C = 0
STC_FS_CONSTANT = 0
STC_FS_DATE = 0
STC_FS_DEFAULT = 0
STC_FS_DEFAULT_C = 0
STC_FS_DISABLEDCODE = 0
STC_FS_IDENTIFIER = 0
STC_FS_IDENTIFIER_C = 0
STC_FS_KEYWORD = 0
STC_FS_KEYWORD2 = 0
STC_FS_KEYWORD2_C = 0
STC_FS_KEYWORD3 = 0
STC_FS_KEYWORD4 = 0
STC_FS_KEYWORD_C = 0
STC_FS_NUMBER = 0
STC_FS_NUMBER_C = 0
STC_FS_OPERATOR = 0
STC_FS_OPERATOR_C = 0
STC_FS_PREPROCESSOR = 0
STC_FS_PREPROCESSOR_C = 0
STC_FS_STRING = 0
STC_FS_STRINGEOL = 0
STC_FS_STRINGEOL_C = 0
STC_FS_STRING_C = 0
STC_FS_WORDOPERATOR = 0
STC_F_COMMENT = 0
STC_F_CONTINUATION = 0
STC_F_DEFAULT = 0
STC_F_IDENTIFIER = 0
STC_F_LABEL = 0
STC_F_NUMBER = 0
STC_F_OPERATOR = 0
STC_F_OPERATOR2 = 0
STC_F_PREPROCESSOR = 0
STC_F_STRING1 = 0
STC_F_STRING2 = 0
STC_F_STRINGEOL = 0
STC_F_WORD = 0
STC_F_WORD2 = 0
STC_F_WORD3 = 0
STC_GAP_CHAR = 0
STC_GAP_COMMENT = 0
STC_GAP_DEFAULT = 0
STC_GAP_IDENTIFIER = 0
STC_GAP_KEYWORD = 0
STC_GAP_KEYWORD2 = 0
STC_GAP_KEYWORD3 = 0
STC_GAP_KEYWORD4 = 0
STC_GAP_NUMBER = 0
STC_GAP_OPERATOR = 0
STC_GAP_STRING = 0
STC_GAP_STRINGEOL = 0
STC_GC_ATTRIBUTE = 0
STC_GC_COMMAND = 0
STC_GC_COMMENTBLOCK = 0
STC_GC_COMMENTLINE = 0
STC_GC_CONTROL = 0
STC_GC_DEFAULT = 0
STC_GC_EVENT = 0
STC_GC_GLOBAL = 0
STC_GC_OPERATOR = 0
STC_GC_STRING = 0
STC_HA_CAPITAL = 0
STC_HA_CHARACTER = 0
STC_HA_CLASS = 0
STC_HA_COMMENTBLOCK = 0
STC_HA_COMMENTBLOCK2 = 0
STC_HA_COMMENTBLOCK3 = 0
STC_HA_COMMENTLINE = 0
STC_HA_DATA = 0
STC_HA_DEFAULT = 0
STC_HA_IDENTIFIER = 0
STC_HA_IMPORT = 0
STC_HA_INSTANCE = 0
STC_HA_KEYWORD = 0
STC_HA_MODULE = 0
STC_HA_NUMBER = 0
STC_HA_OPERATOR = 0
STC_HA_STRING = 0
STC_HBA_COMMENTLINE = 0
STC_HBA_DEFAULT = 0
STC_HBA_IDENTIFIER = 0
STC_HBA_NUMBER = 0
STC_HBA_START = 0
STC_HBA_STRING = 0
STC_HBA_STRINGEOL = 0
STC_HBA_WORD = 0
STC_HB_COMMENTLINE = 0
STC_HB_DEFAULT = 0
STC_HB_IDENTIFIER = 0
STC_HB_NUMBER = 0
STC_HB_START = 0
STC_HB_STRING = 0
STC_HB_STRINGEOL = 0
STC_HB_WORD = 0
STC_HJA_COMMENT = 0
STC_HJA_COMMENTDOC = 0
STC_HJA_COMMENTLINE = 0
STC_HJA_DEFAULT = 0
STC_HJA_DOUBLESTRING = 0
STC_HJA_KEYWORD = 0
STC_HJA_NUMBER = 0
STC_HJA_REGEX = 0
STC_HJA_SINGLESTRING = 0
STC_HJA_START = 0
STC_HJA_STRINGEOL = 0
STC_HJA_SYMBOLS = 0
STC_HJA_WORD = 0
STC_HJ_COMMENT = 0
STC_HJ_COMMENTDOC = 0
STC_HJ_COMMENTLINE = 0
STC_HJ_DEFAULT = 0
STC_HJ_DOUBLESTRING = 0
STC_HJ_KEYWORD = 0
STC_HJ_NUMBER = 0
STC_HJ_REGEX = 0
STC_HJ_SINGLESTRING = 0
STC_HJ_START = 0
STC_HJ_STRINGEOL = 0
STC_HJ_SYMBOLS = 0
STC_HJ_WORD = 0
STC_HPA_CHARACTER = 0
STC_HPA_CLASSNAME = 0
STC_HPA_COMMENTLINE = 0
STC_HPA_DEFAULT = 0
STC_HPA_DEFNAME = 0
STC_HPA_IDENTIFIER = 0
STC_HPA_NUMBER = 0
STC_HPA_OPERATOR = 0
STC_HPA_START = 0
STC_HPA_STRING = 0
STC_HPA_TRIPLE = 0
STC_HPA_TRIPLEDOUBLE = 0
STC_HPA_WORD = 0
STC_HPHP_COMMENT = 0
STC_HPHP_COMMENTLINE = 0
STC_HPHP_COMPLEX_VARIABLE = 0
STC_HPHP_DEFAULT = 0
STC_HPHP_HSTRING = 0
STC_HPHP_HSTRING_VARIABLE = 0
STC_HPHP_NUMBER = 0
STC_HPHP_OPERATOR = 0
STC_HPHP_SIMPLESTRING = 0
STC_HPHP_VARIABLE = 0
STC_HPHP_WORD = 0
STC_HP_CHARACTER = 0
STC_HP_CLASSNAME = 0
STC_HP_COMMENTLINE = 0
STC_HP_DEFAULT = 0
STC_HP_DEFNAME = 0
STC_HP_IDENTIFIER = 0
STC_HP_NUMBER = 0
STC_HP_OPERATOR = 0
STC_HP_START = 0
STC_HP_STRING = 0
STC_HP_TRIPLE = 0
STC_HP_TRIPLEDOUBLE = 0
STC_HP_WORD = 0
STC_H_ASP = 0
STC_H_ASPAT = 0
STC_H_ATTRIBUTE = 0
STC_H_ATTRIBUTEUNKNOWN = 0
STC_H_CDATA = 0
STC_H_COMMENT = 0
STC_H_DEFAULT = 0
STC_H_DOUBLESTRING = 0
STC_H_ENTITY = 0
STC_H_NUMBER = 0
STC_H_OTHER = 0
STC_H_QUESTION = 0
STC_H_SCRIPT = 0
STC_H_SGML_1ST_PARAM = 0
STC_H_SGML_1ST_PARAM_COMMENT = 0
STC_H_SGML_BLOCK_DEFAULT = 0
STC_H_SGML_COMMAND = 0
STC_H_SGML_COMMENT = 0
STC_H_SGML_DEFAULT = 0
STC_H_SGML_DOUBLESTRING = 0
STC_H_SGML_ENTITY = 0
STC_H_SGML_ERROR = 0
STC_H_SGML_SIMPLESTRING = 0
STC_H_SGML_SPECIAL = 0
STC_H_SINGLESTRING = 0
STC_H_TAG = 0
STC_H_TAGEND = 0
STC_H_TAGUNKNOWN = 0
STC_H_VALUE = 0
STC_H_XCCOMMENT = 0
STC_H_XMLEND = 0
STC_H_XMLSTART = 0
STC_INDIC0_MASK = 0
STC_INDIC1_MASK = 0
STC_INDIC2_MASK = 0
STC_INDICS_MASK = 0
STC_INDIC_BOX = 0
STC_INDIC_CONTAINER = 0
STC_INDIC_DASH = 0
STC_INDIC_DIAGONAL = 0
STC_INDIC_DOTBOX = 0
STC_INDIC_DOTS = 0
STC_INDIC_HIDDEN = 0
STC_INDIC_MAX = 0
STC_INDIC_PLAIN = 0
STC_INDIC_ROUNDBOX = 0
STC_INDIC_SQUIGGLE = 0
STC_INDIC_SQUIGGLELOW = 0
STC_INDIC_STRAIGHTBOX = 0
STC_INDIC_STRIKE = 0
STC_INDIC_TT = 0
STC_INNO_COMMENT = 0
STC_INNO_COMMENT_PASCAL = 0
STC_INNO_DEFAULT = 0
STC_INNO_IDENTIFIER = 0
STC_INNO_INLINE_EXPANSION = 0
STC_INNO_KEYWORD = 0
STC_INNO_KEYWORD_PASCAL = 0
STC_INNO_KEYWORD_USER = 0
STC_INNO_PARAMETER = 0
STC_INNO_PREPROC = 0
STC_INNO_SECTION = 0
STC_INNO_STRING_DOUBLE = 0
STC_INNO_STRING_SINGLE = 0
STC_INVALID_POSITION = 0
STC_IV_LOOKBOTH = 0
STC_IV_LOOKFORWARD = 0
STC_IV_NONE = 0
STC_IV_REAL = 0
STC_KEYWORDSET_MAX = 0
STC_KEY_ADD = 0
STC_KEY_BACK = 0
STC_KEY_DELETE = 0
STC_KEY_DIVIDE = 0
STC_KEY_DOWN = 0
STC_KEY_END = 0
STC_KEY_ESCAPE = 0
STC_KEY_HOME = 0
STC_KEY_INSERT = 0
STC_KEY_LEFT = 0
STC_KEY_MENU = 0
STC_KEY_NEXT = 0
STC_KEY_PRIOR = 0
STC_KEY_RETURN = 0
STC_KEY_RIGHT = 0
STC_KEY_RWIN = 0
STC_KEY_SUBTRACT = 0
STC_KEY_TAB = 0
STC_KEY_UP = 0
STC_KEY_WIN = 0
STC_KIX_COMMENT = 0
STC_KIX_DEFAULT = 0
STC_KIX_FUNCTIONS = 0
STC_KIX_IDENTIFIER = 0
STC_KIX_KEYWORD = 0
STC_KIX_MACRO = 0
STC_KIX_NUMBER = 0
STC_KIX_OPERATOR = 0
STC_KIX_STRING1 = 0
STC_KIX_STRING2 = 0
STC_KIX_VAR = 0
STC_LASTSTEPINUNDOREDO = 0
STC_LEXER_START = 0
STC_LEX_A68K = 0
STC_LEX_ABAQUS = 0
STC_LEX_ADA = 0
STC_LEX_APDL = 0
STC_LEX_ASM = 0
STC_LEX_ASN1 = 0
STC_LEX_ASYMPTOTE = 0
STC_LEX_AU3 = 0
STC_LEX_AUTOMATIC = 0
STC_LEX_AVE = 0
STC_LEX_AVS = 0
STC_LEX_BAAN = 0
STC_LEX_BASH = 0
STC_LEX_BATCH = 0
STC_LEX_BLITZBASIC = 0
STC_LEX_BULLANT = 0
STC_LEX_CAML = 0
STC_LEX_CLW = 0
STC_LEX_CLWNOCASE = 0
STC_LEX_CMAKE = 0
STC_LEX_COBOL = 0
STC_LEX_COFFEESCRIPT = 0
STC_LEX_CONF = 0
STC_LEX_CONTAINER = 0
STC_LEX_CPP = 0
STC_LEX_CPPNOCASE = 0
STC_LEX_CSOUND = 0
STC_LEX_CSS = 0
STC_LEX_D = 0
STC_LEX_DIFF = 0
STC_LEX_ECL = 0
STC_LEX_EIFFEL = 0
STC_LEX_EIFFELKW = 0
STC_LEX_ERLANG = 0
STC_LEX_ERRORLIST = 0
STC_LEX_ESCRIPT = 0
STC_LEX_F77 = 0
STC_LEX_FLAGSHIP = 0
STC_LEX_FORTH = 0
STC_LEX_FORTRAN = 0
STC_LEX_FREEBASIC = 0
STC_LEX_GAP = 0
STC_LEX_GUI4CLI = 0
STC_LEX_HASKELL = 0
STC_LEX_HTML = 0
STC_LEX_INNOSETUP = 0
STC_LEX_KIX = 0
STC_LEX_LATEX = 0
STC_LEX_LISP = 0
STC_LEX_LOT = 0
STC_LEX_LOUT = 0
STC_LEX_LUA = 0
STC_LEX_MAGIK = 0
STC_LEX_MAKEFILE = 0
STC_LEX_MARKDOWN = 0
STC_LEX_MATLAB = 0
STC_LEX_METAPOST = 0
STC_LEX_MMIXAL = 0
STC_LEX_MODULA = 0
STC_LEX_MSSQL = 0
STC_LEX_MYSQL = 0
STC_LEX_NIMROD = 0
STC_LEX_NNCRONTAB = 0
STC_LEX_NSIS = 0
STC_LEX_NULL = 0
STC_LEX_OCTAVE = 0
STC_LEX_OPAL = 0
STC_LEX_OSCRIPT = 0
STC_LEX_PASCAL = 0
STC_LEX_PERL = 0
STC_LEX_PHPSCRIPT = 0
STC_LEX_PLM = 0
STC_LEX_PO = 0
STC_LEX_POV = 0
STC_LEX_POWERBASIC = 0
STC_LEX_POWERPRO = 0
STC_LEX_POWERSHELL = 0
STC_LEX_PROGRESS = 0
STC_LEX_PROPERTIES = 0
STC_LEX_PS = 0
STC_LEX_PUREBASIC = 0
STC_LEX_PYTHON = 0
STC_LEX_R = 0
STC_LEX_REBOL = 0
STC_LEX_RUBY = 0
STC_LEX_SCRIPTOL = 0
STC_LEX_SMALLTALK = 0
STC_LEX_SML = 0
STC_LEX_SORCUS = 0
STC_LEX_SPECMAN = 0
STC_LEX_SPICE = 0
STC_LEX_SQL = 0
STC_LEX_TACL = 0
STC_LEX_TADS3 = 0
STC_LEX_TAL = 0
STC_LEX_TCL = 0
STC_LEX_TCMD = 0
STC_LEX_TEX = 0
STC_LEX_TXT2TAGS = 0
STC_LEX_VB = 0
STC_LEX_VBSCRIPT = 0
STC_LEX_VERILOG = 0
STC_LEX_VHDL = 0
STC_LEX_VISUALPROLOG = 0
STC_LEX_XCODE = 0
STC_LEX_XML = 0
STC_LEX_YAML = 0
STC_LISP_COMMENT = 0
STC_LISP_DEFAULT = 0
STC_LISP_IDENTIFIER = 0
STC_LISP_KEYWORD = 0
STC_LISP_KEYWORD_KW = 0
STC_LISP_MULTI_COMMENT = 0
STC_LISP_NUMBER = 0
STC_LISP_OPERATOR = 0
STC_LISP_SPECIAL = 0
STC_LISP_STRING = 0
STC_LISP_STRINGEOL = 0
STC_LISP_SYMBOL = 0
STC_LOT_ABORT = 0
STC_LOT_BREAK = 0
STC_LOT_DEFAULT = 0
STC_LOT_FAIL = 0
STC_LOT_HEADER = 0
STC_LOT_PASS = 0
STC_LOT_SET = 0
STC_LOUT_COMMENT = 0
STC_LOUT_DEFAULT = 0
STC_LOUT_IDENTIFIER = 0
STC_LOUT_NUMBER = 0
STC_LOUT_OPERATOR = 0
STC_LOUT_STRING = 0
STC_LOUT_STRINGEOL = 0
STC_LOUT_WORD = 0
STC_LOUT_WORD2 = 0
STC_LOUT_WORD3 = 0
STC_LOUT_WORD4 = 0
STC_LUA_CHARACTER = 0
STC_LUA_COMMENT = 0
STC_LUA_COMMENTDOC = 0
STC_LUA_COMMENTLINE = 0
STC_LUA_DEFAULT = 0
STC_LUA_IDENTIFIER = 0
STC_LUA_LABEL = 0
STC_LUA_LITERALSTRING = 0
STC_LUA_NUMBER = 0
STC_LUA_OPERATOR = 0
STC_LUA_PREPROCESSOR = 0
STC_LUA_STRING = 0
STC_LUA_STRINGEOL = 0
STC_LUA_WORD = 0
STC_LUA_WORD2 = 0
STC_LUA_WORD3 = 0
STC_LUA_WORD4 = 0
STC_LUA_WORD5 = 0
STC_LUA_WORD6 = 0
STC_LUA_WORD7 = 0
STC_LUA_WORD8 = 0
STC_L_CMDOPT = 0
STC_L_COMMAND = 0
STC_L_COMMENT = 0
STC_L_COMMENT2 = 0
STC_L_DEFAULT = 0
STC_L_ERROR = 0
STC_L_MATH = 0
STC_L_MATH2 = 0
STC_L_SHORTCMD = 0
STC_L_SPECIAL = 0
STC_L_TAG = 0
STC_L_TAG2 = 0
STC_L_VERBATIM = 0
STC_MAGIK_BRACE_BLOCK = 0
STC_MAGIK_BRACKET_BLOCK = 0
STC_MAGIK_CHARACTER = 0
STC_MAGIK_COMMENT = 0
STC_MAGIK_CONTAINER = 0
STC_MAGIK_DEFAULT = 0
STC_MAGIK_FLOW = 0
STC_MAGIK_HYPER_COMMENT = 0
STC_MAGIK_IDENTIFIER = 0
STC_MAGIK_KEYWORD = 0
STC_MAGIK_NUMBER = 0
STC_MAGIK_OPERATOR = 0
STC_MAGIK_PRAGMA = 0
STC_MAGIK_SQBRACKET_BLOCK = 0
STC_MAGIK_STRING = 0
STC_MAGIK_SYMBOL = 0
STC_MAGIK_UNKNOWN_KEYWORD = 0
STC_MAKE_COMMENT = 0
STC_MAKE_DEFAULT = 0
STC_MAKE_IDENTIFIER = 0
STC_MAKE_IDEOL = 0
STC_MAKE_OPERATOR = 0
STC_MAKE_PREPROCESSOR = 0
STC_MAKE_TARGET = 0
STC_MARGINOPTION_NONE = 0
STC_MARGINOPTION_SUBLINESELECT = 0
STC_MARGIN_BACK = 0
STC_MARGIN_FORE = 0
STC_MARGIN_NUMBER = 0
STC_MARGIN_RTEXT = 0
STC_MARGIN_SYMBOL = 0
STC_MARGIN_TEXT = 0
STC_MARKDOWN_BLOCKQUOTE = 0
STC_MARKDOWN_CODE = 0
STC_MARKDOWN_CODE2 = 0
STC_MARKDOWN_CODEBK = 0
STC_MARKDOWN_DEFAULT = 0
STC_MARKDOWN_EM1 = 0
STC_MARKDOWN_EM2 = 0
STC_MARKDOWN_HEADER1 = 0
STC_MARKDOWN_HEADER2 = 0
STC_MARKDOWN_HEADER3 = 0
STC_MARKDOWN_HEADER4 = 0
STC_MARKDOWN_HEADER5 = 0
STC_MARKDOWN_HEADER6 = 0
STC_MARKDOWN_HRULE = 0
STC_MARKDOWN_LINE_BEGIN = 0
STC_MARKDOWN_LINK = 0
STC_MARKDOWN_OLIST_ITEM = 0
STC_MARKDOWN_PRECHAR = 0
STC_MARKDOWN_STRIKEOUT = 0
STC_MARKDOWN_STRONG1 = 0
STC_MARKDOWN_STRONG2 = 0
STC_MARKDOWN_ULIST_ITEM = 0
STC_MARKER_MAX = 0
STC_MARKNUM_FOLDER = 0
STC_MARKNUM_FOLDEREND = 0
STC_MARKNUM_FOLDERMIDTAIL = 0
STC_MARKNUM_FOLDEROPEN = 0
STC_MARKNUM_FOLDEROPENMID = 0
STC_MARKNUM_FOLDERSUB = 0
STC_MARKNUM_FOLDERTAIL = 0
STC_MARK_ARROW = 0
STC_MARK_ARROWDOWN = 0
STC_MARK_ARROWS = 0
STC_MARK_AVAILABLE = 0
STC_MARK_BACKGROUND = 0
STC_MARK_BOXMINUS = 0
STC_MARK_BOXMINUSCONNECTED = 0
STC_MARK_BOXPLUS = 0
STC_MARK_BOXPLUSCONNECTED = 0
STC_MARK_CHARACTER = 0
STC_MARK_CIRCLE = 0
STC_MARK_CIRCLEMINUS = 0
STC_MARK_CIRCLEMINUSCONNECTED = 0
STC_MARK_CIRCLEPLUS = 0
STC_MARK_CIRCLEPLUSCONNECTED = 0
STC_MARK_DOTDOTDOT = 0
STC_MARK_EMPTY = 0
STC_MARK_FULLRECT = 0
STC_MARK_LCORNER = 0
STC_MARK_LCORNERCURVE = 0
STC_MARK_LEFTRECT = 0
STC_MARK_MINUS = 0
STC_MARK_PIXMAP = 0
STC_MARK_PLUS = 0
STC_MARK_RGBAIMAGE = 0
STC_MARK_ROUNDRECT = 0
STC_MARK_SHORTARROW = 0
STC_MARK_SMALLRECT = 0
STC_MARK_TCORNER = 0
STC_MARK_TCORNERCURVE = 0
STC_MARK_UNDERLINE = 0
STC_MARK_VLINE = 0
STC_MASK_FOLDERS = 0
STC_MATLAB_COMMAND = 0
STC_MATLAB_COMMENT = 0
STC_MATLAB_DEFAULT = 0
STC_MATLAB_DOUBLEQUOTESTRING = 0
STC_MATLAB_IDENTIFIER = 0
STC_MATLAB_KEYWORD = 0
STC_MATLAB_NUMBER = 0
STC_MATLAB_OPERATOR = 0
STC_MATLAB_STRING = 0
STC_METAPOST_COMMAND = 0
STC_METAPOST_DEFAULT = 0
STC_METAPOST_EXTRA = 0
STC_METAPOST_GROUP = 0
STC_METAPOST_SPECIAL = 0
STC_METAPOST_SYMBOL = 0
STC_METAPOST_TEXT = 0
STC_MMIXAL_CHAR = 0
STC_MMIXAL_COMMENT = 0
STC_MMIXAL_HEX = 0
STC_MMIXAL_INCLUDE = 0
STC_MMIXAL_LABEL = 0
STC_MMIXAL_LEADWS = 0
STC_MMIXAL_NUMBER = 0
STC_MMIXAL_OPCODE = 0
STC_MMIXAL_OPCODE_POST = 0
STC_MMIXAL_OPCODE_PRE = 0
STC_MMIXAL_OPCODE_UNKNOWN = 0
STC_MMIXAL_OPCODE_VALID = 0
STC_MMIXAL_OPERANDS = 0
STC_MMIXAL_OPERATOR = 0
STC_MMIXAL_REF = 0
STC_MMIXAL_REGISTER = 0
STC_MMIXAL_STRING = 0
STC_MMIXAL_SYMBOL = 0
STC_MODEVENTMASKALL = 0
STC_MODULA_BADSTR = 0
STC_MODULA_BASENUM = 0
STC_MODULA_CHAR = 0
STC_MODULA_CHARSPEC = 0
STC_MODULA_COMMENT = 0
STC_MODULA_DEFAULT = 0
STC_MODULA_DOXYCOMM = 0
STC_MODULA_DOXYKEY = 0
STC_MODULA_FLOAT = 0
STC_MODULA_KEYWORD = 0
STC_MODULA_NUMBER = 0
STC_MODULA_OPERATOR = 0
STC_MODULA_PRAGMA = 0
STC_MODULA_PRGKEY = 0
STC_MODULA_PROC = 0
STC_MODULA_RESERVED = 0
STC_MODULA_STRING = 0
STC_MODULA_STRSPEC = 0
STC_MOD_BEFOREDELETE = 0
STC_MOD_BEFOREINSERT = 0
STC_MOD_CHANGEANNOTATION = 0
STC_MOD_CHANGEFOLD = 0
STC_MOD_CHANGEINDICATOR = 0
STC_MOD_CHANGELINESTATE = 0
STC_MOD_CHANGEMARGIN = 0
STC_MOD_CHANGEMARKER = 0
STC_MOD_CHANGESTYLE = 0
STC_MOD_CONTAINER = 0
STC_MOD_DELETETEXT = 0
STC_MOD_INSERTTEXT = 0
STC_MOD_LEXERSTATE = 0
STC_MSSQL_COLUMN_NAME = 0
STC_MSSQL_COLUMN_NAME_2 = 0
STC_MSSQL_COMMENT = 0
STC_MSSQL_DATATYPE = 0
STC_MSSQL_DEFAULT = 0
STC_MSSQL_DEFAULT_PREF_DATATYPE = 0
STC_MSSQL_FUNCTION = 0
STC_MSSQL_GLOBAL_VARIABLE = 0
STC_MSSQL_IDENTIFIER = 0
STC_MSSQL_LINE_COMMENT = 0
STC_MSSQL_NUMBER = 0
STC_MSSQL_OPERATOR = 0
STC_MSSQL_STATEMENT = 0
STC_MSSQL_STORED_PROCEDURE = 0
STC_MSSQL_STRING = 0
STC_MSSQL_SYSTABLE = 0
STC_MSSQL_VARIABLE = 0
STC_MULTILINEUNDOREDO = 0
STC_MULTIPASTE_EACH = 0
STC_MULTIPASTE_ONCE = 0
STC_MULTISTEPUNDOREDO = 0
STC_MYSQL_COMMENT = 0
STC_MYSQL_COMMENTLINE = 0
STC_MYSQL_DATABASEOBJECT = 0
STC_MYSQL_DEFAULT = 0
STC_MYSQL_DQSTRING = 0
STC_MYSQL_FUNCTION = 0
STC_MYSQL_HIDDENCOMMAND = 0
STC_MYSQL_IDENTIFIER = 0
STC_MYSQL_KEYWORD = 0
STC_MYSQL_KNOWNSYSTEMVARIABLE = 0
STC_MYSQL_MAJORKEYWORD = 0
STC_MYSQL_NUMBER = 0
STC_MYSQL_OPERATOR = 0
STC_MYSQL_PROCEDUREKEYWORD = 0
STC_MYSQL_QUOTEDIDENTIFIER = 0
STC_MYSQL_SQSTRING = 0
STC_MYSQL_STRING = 0
STC_MYSQL_SYSTEMVARIABLE = 0
STC_MYSQL_USER1 = 0
STC_MYSQL_USER2 = 0
STC_MYSQL_USER3 = 0
STC_MYSQL_VARIABLE = 0
STC_NNCRONTAB_ASTERISK = 0
STC_NNCRONTAB_COMMENT = 0
STC_NNCRONTAB_DEFAULT = 0
STC_NNCRONTAB_ENVIRONMENT = 0
STC_NNCRONTAB_IDENTIFIER = 0
STC_NNCRONTAB_KEYWORD = 0
STC_NNCRONTAB_MODIFIER = 0
STC_NNCRONTAB_NUMBER = 0
STC_NNCRONTAB_SECTION = 0
STC_NNCRONTAB_STRING = 0
STC_NNCRONTAB_TASK = 0
STC_NSIS_COMMENT = 0
STC_NSIS_COMMENTBOX = 0
STC_NSIS_DEFAULT = 0
STC_NSIS_FUNCTION = 0
STC_NSIS_FUNCTIONDEF = 0
STC_NSIS_IFDEFINEDEF = 0
STC_NSIS_LABEL = 0
STC_NSIS_MACRODEF = 0
STC_NSIS_NUMBER = 0
STC_NSIS_PAGEEX = 0
STC_NSIS_SECTIONDEF = 0
STC_NSIS_SECTIONGROUP = 0
STC_NSIS_STRINGDQ = 0
STC_NSIS_STRINGLQ = 0
STC_NSIS_STRINGRQ = 0
STC_NSIS_STRINGVAR = 0
STC_NSIS_SUBSECTIONDEF = 0
STC_NSIS_USERDEFINED = 0
STC_NSIS_VARIABLE = 0
STC_OPAL_BOOL_CONST = 0
STC_OPAL_COMMENT_BLOCK = 0
STC_OPAL_COMMENT_LINE = 0
STC_OPAL_DEFAULT = 0
STC_OPAL_INTEGER = 0
STC_OPAL_KEYWORD = 0
STC_OPAL_PAR = 0
STC_OPAL_SORT = 0
STC_OPAL_SPACE = 0
STC_OPAL_STRING = 0
STC_OPTIONAL_START = 0
STC_OSCRIPT_BLOCK_COMMENT = 0
STC_OSCRIPT_CONSTANT = 0
STC_OSCRIPT_DEFAULT = 0
STC_OSCRIPT_DOC_COMMENT = 0
STC_OSCRIPT_DOUBLEQUOTE_STRING = 0
STC_OSCRIPT_FUNCTION = 0
STC_OSCRIPT_GLOBAL = 0
STC_OSCRIPT_IDENTIFIER = 0
STC_OSCRIPT_KEYWORD = 0
STC_OSCRIPT_LABEL = 0
STC_OSCRIPT_LINE_COMMENT = 0
STC_OSCRIPT_METHOD = 0
STC_OSCRIPT_NUMBER = 0
STC_OSCRIPT_OBJECT = 0
STC_OSCRIPT_OPERATOR = 0
STC_OSCRIPT_PREPROCESSOR = 0
STC_OSCRIPT_PROPERTY = 0
STC_OSCRIPT_SINGLEQUOTE_STRING = 0
STC_OSCRIPT_TYPE = 0
STC_PAS_ASM = 0
STC_PAS_CHARACTER = 0
STC_PAS_COMMENT = 0
STC_PAS_COMMENT2 = 0
STC_PAS_COMMENTLINE = 0
STC_PAS_DEFAULT = 0
STC_PAS_HEXNUMBER = 0
STC_PAS_IDENTIFIER = 0
STC_PAS_NUMBER = 0
STC_PAS_OPERATOR = 0
STC_PAS_PREPROCESSOR = 0
STC_PAS_PREPROCESSOR2 = 0
STC_PAS_STRING = 0
STC_PAS_STRINGEOL = 0
STC_PAS_WORD = 0
STC_PERFORMED_REDO = 0
STC_PERFORMED_UNDO = 0
STC_PERFORMED_USER = 0
STC_PLM_COMMENT = 0
STC_PLM_CONTROL = 0
STC_PLM_DEFAULT = 0
STC_PLM_IDENTIFIER = 0
STC_PLM_KEYWORD = 0
STC_PLM_NUMBER = 0
STC_PLM_OPERATOR = 0
STC_PLM_STRING = 0
STC_PL_ARRAY = 0
STC_PL_BACKTICKS = 0
STC_PL_BACKTICKS_VAR = 0
STC_PL_CHARACTER = 0
STC_PL_COMMENTLINE = 0
STC_PL_DATASECTION = 0
STC_PL_DEFAULT = 0
STC_PL_ERROR = 0
STC_PL_FORMAT = 0
STC_PL_FORMAT_IDENT = 0
STC_PL_HASH = 0
STC_PL_HERE_DELIM = 0
STC_PL_HERE_Q = 0
STC_PL_HERE_QQ = 0
STC_PL_HERE_QQ_VAR = 0
STC_PL_HERE_QX = 0
STC_PL_HERE_QX_VAR = 0
STC_PL_IDENTIFIER = 0
STC_PL_LONGQUOTE = 0
STC_PL_NUMBER = 0
STC_PL_OPERATOR = 0
STC_PL_POD = 0
STC_PL_POD_VERB = 0
STC_PL_PREPROCESSOR = 0
STC_PL_PUNCTUATION = 0
STC_PL_REGEX = 0
STC_PL_REGEX_VAR = 0
STC_PL_REGSUBST = 0
STC_PL_REGSUBST_VAR = 0
STC_PL_SCALAR = 0
STC_PL_STRING = 0
STC_PL_STRING_Q = 0
STC_PL_STRING_QQ = 0
STC_PL_STRING_QQ_VAR = 0
STC_PL_STRING_QR = 0
STC_PL_STRING_QR_VAR = 0
STC_PL_STRING_QW = 0
STC_PL_STRING_QX = 0
STC_PL_STRING_QX_VAR = 0
STC_PL_STRING_VAR = 0
STC_PL_SUB_PROTOTYPE = 0
STC_PL_SYMBOLTABLE = 0
STC_PL_VARIABLE_INDEXER = 0
STC_PL_WORD = 0
STC_PL_XLAT = 0
STC_POV_BADDIRECTIVE = 0
STC_POV_COMMENT = 0
STC_POV_COMMENTLINE = 0
STC_POV_DEFAULT = 0
STC_POV_DIRECTIVE = 0
STC_POV_IDENTIFIER = 0
STC_POV_NUMBER = 0
STC_POV_OPERATOR = 0
STC_POV_STRING = 0
STC_POV_STRINGEOL = 0
STC_POV_WORD2 = 0
STC_POV_WORD3 = 0
STC_POV_WORD4 = 0
STC_POV_WORD5 = 0
STC_POV_WORD6 = 0
STC_POV_WORD7 = 0
STC_POV_WORD8 = 0
STC_POWERPRO_ALTQUOTE = 0
STC_POWERPRO_COMMENTBLOCK = 0
STC_POWERPRO_COMMENTLINE = 0
STC_POWERPRO_DEFAULT = 0
STC_POWERPRO_DOUBLEQUOTEDSTRING = 0
STC_POWERPRO_FUNCTION = 0
STC_POWERPRO_IDENTIFIER = 0
STC_POWERPRO_LINECONTINUE = 0
STC_POWERPRO_NUMBER = 0
STC_POWERPRO_OPERATOR = 0
STC_POWERPRO_SINGLEQUOTEDSTRING = 0
STC_POWERPRO_STRINGEOL = 0
STC_POWERPRO_VERBATIM = 0
STC_POWERPRO_WORD = 0
STC_POWERPRO_WORD2 = 0
STC_POWERPRO_WORD3 = 0
STC_POWERPRO_WORD4 = 0
STC_POWERSHELL_ALIAS = 0
STC_POWERSHELL_CHARACTER = 0
STC_POWERSHELL_CMDLET = 0
STC_POWERSHELL_COMMENT = 0
STC_POWERSHELL_COMMENTSTREAM = 0
STC_POWERSHELL_DEFAULT = 0
STC_POWERSHELL_FUNCTION = 0
STC_POWERSHELL_IDENTIFIER = 0
STC_POWERSHELL_KEYWORD = 0
STC_POWERSHELL_NUMBER = 0
STC_POWERSHELL_OPERATOR = 0
STC_POWERSHELL_STRING = 0
STC_POWERSHELL_USER1 = 0
STC_POWERSHELL_VARIABLE = 0
STC_PO_COMMENT = 0
STC_PO_DEFAULT = 0
STC_PO_FUZZY = 0
STC_PO_MSGCTXT = 0
STC_PO_MSGCTXT_TEXT = 0
STC_PO_MSGID = 0
STC_PO_MSGID_TEXT = 0
STC_PO_MSGSTR = 0
STC_PO_MSGSTR_TEXT = 0
STC_PRINT_BLACKONWHITE = 0
STC_PRINT_COLOURONWHITE = 0
STC_PRINT_COLOURONWHITEDEFAULTBG = 0
STC_PRINT_INVERTLIGHT = 0
STC_PRINT_NORMAL = 0
STC_PROPS_ASSIGNMENT = 0
STC_PROPS_COMMENT = 0
STC_PROPS_DEFAULT = 0
STC_PROPS_DEFVAL = 0
STC_PROPS_KEY = 0
STC_PROPS_SECTION = 0
STC_PS_BADSTRINGCHAR = 0
STC_PS_BASE85STRING = 0
STC_PS_COMMENT = 0
STC_PS_DEFAULT = 0
STC_PS_DSC_COMMENT = 0
STC_PS_DSC_VALUE = 0
STC_PS_HEXSTRING = 0
STC_PS_IMMEVAL = 0
STC_PS_KEYWORD = 0
STC_PS_LITERAL = 0
STC_PS_NAME = 0
STC_PS_NUMBER = 0
STC_PS_PAREN_ARRAY = 0
STC_PS_PAREN_DICT = 0
STC_PS_PAREN_PROC = 0
STC_PS_TEXT = 0
STC_P_CHARACTER = 0
STC_P_CLASSNAME = 0
STC_P_COMMENTBLOCK = 0
STC_P_COMMENTLINE = 0
STC_P_DECORATOR = 0
STC_P_DEFAULT = 0
STC_P_DEFNAME = 0
STC_P_IDENTIFIER = 0
STC_P_NUMBER = 0
STC_P_OPERATOR = 0
STC_P_STRING = 0
STC_P_STRINGEOL = 0
STC_P_TRIPLE = 0
STC_P_TRIPLEDOUBLE = 0
STC_P_WORD = 0
STC_P_WORD2 = 0
STC_RB_BACKTICKS = 0
STC_RB_CHARACTER = 0
STC_RB_CLASSNAME = 0
STC_RB_CLASS_VAR = 0
STC_RB_COMMENTLINE = 0
STC_RB_DATASECTION = 0
STC_RB_DEFAULT = 0
STC_RB_DEFNAME = 0
STC_RB_ERROR = 0
STC_RB_GLOBAL = 0
STC_RB_HERE_DELIM = 0
STC_RB_HERE_Q = 0
STC_RB_HERE_QQ = 0
STC_RB_HERE_QX = 0
STC_RB_IDENTIFIER = 0
STC_RB_INSTANCE_VAR = 0
STC_RB_MODULE_NAME = 0
STC_RB_NUMBER = 0
STC_RB_OPERATOR = 0
STC_RB_POD = 0
STC_RB_REGEX = 0
STC_RB_STDERR = 0
STC_RB_STDIN = 0
STC_RB_STDOUT = 0
STC_RB_STRING = 0
STC_RB_STRING_Q = 0
STC_RB_STRING_QQ = 0
STC_RB_STRING_QR = 0
STC_RB_STRING_QW = 0
STC_RB_STRING_QX = 0
STC_RB_SYMBOL = 0
STC_RB_UPPER_BOUND = 0
STC_RB_WORD = 0
STC_RB_WORD_DEMOTED = 0
STC_REBOL_BINARY = 0
STC_REBOL_BRACEDSTRING = 0
STC_REBOL_CHARACTER = 0
STC_REBOL_COMMENTBLOCK = 0
STC_REBOL_COMMENTLINE = 0
STC_REBOL_DATE = 0
STC_REBOL_DEFAULT = 0
STC_REBOL_EMAIL = 0
STC_REBOL_FILE = 0
STC_REBOL_IDENTIFIER = 0
STC_REBOL_ISSUE = 0
STC_REBOL_MONEY = 0
STC_REBOL_NUMBER = 0
STC_REBOL_OPERATOR = 0
STC_REBOL_PAIR = 0
STC_REBOL_PREFACE = 0
STC_REBOL_QUOTEDSTRING = 0
STC_REBOL_TAG = 0
STC_REBOL_TIME = 0
STC_REBOL_TUPLE = 0
STC_REBOL_URL = 0
STC_REBOL_WORD = 0
STC_REBOL_WORD2 = 0
STC_REBOL_WORD3 = 0
STC_REBOL_WORD4 = 0
STC_REBOL_WORD5 = 0
STC_REBOL_WORD6 = 0
STC_REBOL_WORD7 = 0
STC_REBOL_WORD8 = 0
STC_R_BASEKWORD = 0
STC_R_COMMENT = 0
STC_R_DEFAULT = 0
STC_R_IDENTIFIER = 0
STC_R_INFIX = 0
STC_R_INFIXEOL = 0
STC_R_KWORD = 0
STC_R_NUMBER = 0
STC_R_OPERATOR = 0
STC_R_OTHERKWORD = 0
STC_R_STRING = 0
STC_R_STRING2 = 0
STC_SCMOD_ALT = 0
STC_SCMOD_CTRL = 0
STC_SCMOD_META = 0
STC_SCMOD_NORM = 0
STC_SCMOD_SHIFT = 0
STC_SCMOD_SUPER = 0
STC_SCRIPTOL_CHARACTER = 0
STC_SCRIPTOL_CLASSNAME = 0
STC_SCRIPTOL_COMMENTBLOCK = 0
STC_SCRIPTOL_COMMENTLINE = 0
STC_SCRIPTOL_CSTYLE = 0
STC_SCRIPTOL_DEFAULT = 0
STC_SCRIPTOL_IDENTIFIER = 0
STC_SCRIPTOL_KEYWORD = 0
STC_SCRIPTOL_NUMBER = 0
STC_SCRIPTOL_OPERATOR = 0
STC_SCRIPTOL_PERSISTENT = 0
STC_SCRIPTOL_PREPROCESSOR = 0
STC_SCRIPTOL_STRING = 0
STC_SCRIPTOL_STRINGEOL = 0
STC_SCRIPTOL_TRIPLE = 0
STC_SCRIPTOL_WHITE = 0
STC_SCVS_NONE = 0
STC_SCVS_RECTANGULARSELECTION = 0
STC_SCVS_USERACCESSIBLE = 0
STC_SEL_LINES = 0
STC_SEL_RECTANGLE = 0
STC_SEL_STREAM = 0
STC_SEL_THIN = 0
STC_SH_BACKTICKS = 0
STC_SH_CHARACTER = 0
STC_SH_COMMENTLINE = 0
STC_SH_DEFAULT = 0
STC_SH_ERROR = 0
STC_SH_HERE_DELIM = 0
STC_SH_HERE_Q = 0
STC_SH_IDENTIFIER = 0
STC_SH_NUMBER = 0
STC_SH_OPERATOR = 0
STC_SH_PARAM = 0
STC_SH_SCALAR = 0
STC_SH_STRING = 0
STC_SH_WORD = 0
STC_SML_CHAR = 0
STC_SML_COMMENT = 0
STC_SML_COMMENT1 = 0
STC_SML_COMMENT2 = 0
STC_SML_COMMENT3 = 0
STC_SML_DEFAULT = 0
STC_SML_IDENTIFIER = 0
STC_SML_KEYWORD = 0
STC_SML_KEYWORD2 = 0
STC_SML_KEYWORD3 = 0
STC_SML_LINENUM = 0
STC_SML_NUMBER = 0
STC_SML_OPERATOR = 0
STC_SML_STRING = 0
STC_SML_TAGNAME = 0
STC_SN_CODE = 0
STC_SN_COMMENTLINE = 0
STC_SN_COMMENTLINEBANG = 0
STC_SN_DEFAULT = 0
STC_SN_IDENTIFIER = 0
STC_SN_NUMBER = 0
STC_SN_OPERATOR = 0
STC_SN_PREPROCESSOR = 0
STC_SN_REGEXTAG = 0
STC_SN_SIGNAL = 0
STC_SN_STRING = 0
STC_SN_STRINGEOL = 0
STC_SN_USER = 0
STC_SN_WORD = 0
STC_SN_WORD2 = 0
STC_SN_WORD3 = 0
STC_SORCUS_COMMAND = 0
STC_SORCUS_COMMENTLINE = 0
STC_SORCUS_CONSTANT = 0
STC_SORCUS_DEFAULT = 0
STC_SORCUS_IDENTIFIER = 0
STC_SORCUS_NUMBER = 0
STC_SORCUS_OPERATOR = 0
STC_SORCUS_PARAMETER = 0
STC_SORCUS_STRING = 0
STC_SORCUS_STRINGEOL = 0
STC_SPICE_COMMENTLINE = 0
STC_SPICE_DEFAULT = 0
STC_SPICE_DELIMITER = 0
STC_SPICE_IDENTIFIER = 0
STC_SPICE_KEYWORD = 0
STC_SPICE_KEYWORD2 = 0
STC_SPICE_KEYWORD3 = 0
STC_SPICE_NUMBER = 0
STC_SPICE_VALUE = 0
STC_SQL_CHARACTER = 0
STC_SQL_COMMENT = 0
STC_SQL_COMMENTDOC = 0
STC_SQL_COMMENTDOCKEYWORD = 0
STC_SQL_COMMENTDOCKEYWORDERROR = 0
STC_SQL_COMMENTLINE = 0
STC_SQL_COMMENTLINEDOC = 0
STC_SQL_DEFAULT = 0
STC_SQL_IDENTIFIER = 0
STC_SQL_NUMBER = 0
STC_SQL_OPERATOR = 0
STC_SQL_QUOTEDIDENTIFIER = 0
STC_SQL_SQLPLUS = 0
STC_SQL_SQLPLUS_COMMENT = 0
STC_SQL_SQLPLUS_PROMPT = 0
STC_SQL_STRING = 0
STC_SQL_USER1 = 0
STC_SQL_USER2 = 0
STC_SQL_USER3 = 0
STC_SQL_USER4 = 0
STC_SQL_WORD = 0
STC_SQL_WORD2 = 0
STC_START = 0
STC_STARTACTION = 0
STC_STATUS_BADALLOC = 0
STC_STATUS_FAILURE = 0
STC_STATUS_OK = 0
STC_STYLE_BRACEBAD = 0
STC_STYLE_BRACELIGHT = 0
STC_STYLE_CALLTIP = 0
STC_STYLE_CONTROLCHAR = 0
STC_STYLE_DEFAULT = 0
STC_STYLE_INDENTGUIDE = 0
STC_STYLE_LASTPREDEFINED = 0
STC_STYLE_LINENUMBER = 0
STC_STYLE_MAX = 0
STC_ST_ASSIGN = 0
STC_ST_BINARY = 0
STC_ST_BOOL = 0
STC_ST_CHARACTER = 0
STC_ST_COMMENT = 0
STC_ST_DEFAULT = 0
STC_ST_GLOBAL = 0
STC_ST_KWSEND = 0
STC_ST_NIL = 0
STC_ST_NUMBER = 0
STC_ST_RETURN = 0
STC_ST_SELF = 0
STC_ST_SPECIAL = 0
STC_ST_SPEC_SEL = 0
STC_ST_STRING = 0
STC_ST_SUPER = 0
STC_ST_SYMBOL = 0
STC_T3_BLOCK_COMMENT = 0
STC_T3_BRACE = 0
STC_T3_DEFAULT = 0
STC_T3_D_STRING = 0
STC_T3_HTML_DEFAULT = 0
STC_T3_HTML_STRING = 0
STC_T3_HTML_TAG = 0
STC_T3_IDENTIFIER = 0
STC_T3_KEYWORD = 0
STC_T3_LIB_DIRECTIVE = 0
STC_T3_LINE_COMMENT = 0
STC_T3_MSG_PARAM = 0
STC_T3_NUMBER = 0
STC_T3_OPERATOR = 0
STC_T3_PREPROCESSOR = 0
STC_T3_S_STRING = 0
STC_T3_USER1 = 0
STC_T3_USER2 = 0
STC_T3_USER3 = 0
STC_T3_X_DEFAULT = 0
STC_T3_X_STRING = 0
STC_TCL_BLOCK_COMMENT = 0
STC_TCL_COMMENT = 0
STC_TCL_COMMENTLINE = 0
STC_TCL_COMMENT_BOX = 0
STC_TCL_DEFAULT = 0
STC_TCL_EXPAND = 0
STC_TCL_IDENTIFIER = 0
STC_TCL_IN_QUOTE = 0
STC_TCL_MODIFIER = 0
STC_TCL_NUMBER = 0
STC_TCL_OPERATOR = 0
STC_TCL_SUBSTITUTION = 0
STC_TCL_SUB_BRACE = 0
STC_TCL_WORD = 0
STC_TCL_WORD2 = 0
STC_TCL_WORD3 = 0
STC_TCL_WORD4 = 0
STC_TCL_WORD5 = 0
STC_TCL_WORD6 = 0
STC_TCL_WORD7 = 0
STC_TCL_WORD8 = 0
STC_TCL_WORD_IN_QUOTE = 0
STC_TCMD_CLABEL = 0
STC_TCMD_COMMAND = 0
STC_TCMD_COMMENT = 0
STC_TCMD_DEFAULT = 0
STC_TCMD_ENVIRONMENT = 0
STC_TCMD_EXPANSION = 0
STC_TCMD_HIDE = 0
STC_TCMD_IDENTIFIER = 0
STC_TCMD_LABEL = 0
STC_TCMD_OPERATOR = 0
STC_TCMD_WORD = 0
STC_TECHNOLOGY_DEFAULT = 0
STC_TECHNOLOGY_DIRECTWRITE = 0
STC_TEX_COMMAND = 0
STC_TEX_DEFAULT = 0
STC_TEX_GROUP = 0
STC_TEX_SPECIAL = 0
STC_TEX_SYMBOL = 0
STC_TEX_TEXT = 0
STC_TIME_FOREVER = 0
STC_TXT2TAGS_BLOCKQUOTE = 0
STC_TXT2TAGS_CODE = 0
STC_TXT2TAGS_CODE2 = 0
STC_TXT2TAGS_CODEBK = 0
STC_TXT2TAGS_COMMENT = 0
STC_TXT2TAGS_DEFAULT = 0
STC_TXT2TAGS_EM1 = 0
STC_TXT2TAGS_EM2 = 0
STC_TXT2TAGS_HEADER1 = 0
STC_TXT2TAGS_HEADER2 = 0
STC_TXT2TAGS_HEADER3 = 0
STC_TXT2TAGS_HEADER4 = 0
STC_TXT2TAGS_HEADER5 = 0
STC_TXT2TAGS_HEADER6 = 0
STC_TXT2TAGS_HRULE = 0
STC_TXT2TAGS_LINE_BEGIN = 0
STC_TXT2TAGS_LINK = 0
STC_TXT2TAGS_OLIST_ITEM = 0
STC_TXT2TAGS_OPTION = 0
STC_TXT2TAGS_POSTPROC = 0
STC_TXT2TAGS_PRECHAR = 0
STC_TXT2TAGS_PREPROC = 0
STC_TXT2TAGS_STRIKEOUT = 0
STC_TXT2TAGS_STRONG1 = 0
STC_TXT2TAGS_STRONG2 = 0
STC_TXT2TAGS_ULIST_ITEM = 0
STC_TYPE_BOOLEAN = 0
STC_TYPE_INTEGER = 0
STC_TYPE_STRING = 0
STC_UNDO_MAY_COALESCE = 0
STC_UPDATE_CONTENT = 0
STC_UPDATE_H_SCROLL = 0
STC_UPDATE_SELECTION = 0
STC_UPDATE_V_SCROLL = 0
STC_VHDL_ATTRIBUTE = 0
STC_VHDL_COMMENT = 0
STC_VHDL_COMMENTLINEBANG = 0
STC_VHDL_DEFAULT = 0
STC_VHDL_IDENTIFIER = 0
STC_VHDL_KEYWORD = 0
STC_VHDL_NUMBER = 0
STC_VHDL_OPERATOR = 0
STC_VHDL_STDFUNCTION = 0
STC_VHDL_STDOPERATOR = 0
STC_VHDL_STDPACKAGE = 0
STC_VHDL_STDTYPE = 0
STC_VHDL_STRING = 0
STC_VHDL_STRINGEOL = 0
STC_VHDL_USERWORD = 0
STC_VISIBLE_SLOP = 0
STC_VISIBLE_STRICT = 0
STC_VISUALPROLOG_ANONYMOUS = 0
STC_VISUALPROLOG_CHARACTER = 0
STC_VISUALPROLOG_CHARACTER_ESCAPE_ERROR = 0
STC_VISUALPROLOG_CHARACTER_TOO_MANY = 0
STC_VISUALPROLOG_COMMENT_BLOCK = 0
STC_VISUALPROLOG_COMMENT_KEY = 0
STC_VISUALPROLOG_COMMENT_KEY_ERROR = 0
STC_VISUALPROLOG_COMMENT_LINE = 0
STC_VISUALPROLOG_DEFAULT = 0
STC_VISUALPROLOG_IDENTIFIER = 0
STC_VISUALPROLOG_KEY_DIRECTIVE = 0
STC_VISUALPROLOG_KEY_MAJOR = 0
STC_VISUALPROLOG_KEY_MINOR = 0
STC_VISUALPROLOG_NUMBER = 0
STC_VISUALPROLOG_OPERATOR = 0
STC_VISUALPROLOG_STRING = 0
STC_VISUALPROLOG_STRING_EOL_OPEN = 0
STC_VISUALPROLOG_STRING_ESCAPE = 0
STC_VISUALPROLOG_STRING_ESCAPE_ERROR = 0
STC_VISUALPROLOG_STRING_VERBATIM = 0
STC_VISUALPROLOG_STRING_VERBATIM_EOL = 0
STC_VISUALPROLOG_STRING_VERBATIM_SPECIAL = 0
STC_VISUALPROLOG_VARIABLE = 0
STC_V_COMMENT = 0
STC_V_COMMENTLINE = 0
STC_V_COMMENTLINEBANG = 0
STC_V_DEFAULT = 0
STC_V_IDENTIFIER = 0
STC_V_NUMBER = 0
STC_V_OPERATOR = 0
STC_V_PREPROCESSOR = 0
STC_V_STRING = 0
STC_V_STRINGEOL = 0
STC_V_USER = 0
STC_V_WORD = 0
STC_V_WORD2 = 0
STC_V_WORD3 = 0
STC_WEIGHT_BOLD = 0
STC_WEIGHT_NORMAL = 0
STC_WEIGHT_SEMIBOLD = 0
STC_WRAPINDENT_FIXED = 0
STC_WRAPINDENT_INDENT = 0
STC_WRAPINDENT_SAME = 0
STC_WRAPVISUALFLAGLOC_DEFAULT = 0
STC_WRAPVISUALFLAGLOC_END_BY_TEXT = 0
STC_WRAPVISUALFLAGLOC_START_BY_TEXT = 0
STC_WRAPVISUALFLAG_END = 0
STC_WRAPVISUALFLAG_MARGIN = 0
STC_WRAPVISUALFLAG_NONE = 0
STC_WRAPVISUALFLAG_START = 0
STC_WRAP_CHAR = 0
STC_WRAP_NONE = 0
STC_WRAP_WORD = 0
STC_WS_INVISIBLE = 0
STC_WS_VISIBLEAFTERINDENT = 0
STC_WS_VISIBLEALWAYS = 0
STC_YAML_COMMENT = 0
STC_YAML_DEFAULT = 0
STC_YAML_DOCUMENT = 0
STC_YAML_ERROR = 0
STC_YAML_IDENTIFIER = 0
STC_YAML_KEYWORD = 0
STC_YAML_NUMBER = 0
STC_YAML_OPERATOR = 0
STC_YAML_REFERENCE = 0
STC_YAML_TEXT = 0
StyledTextCtrl = object
StyledTextEvent = object
wxEVT_STC_AUTOCOMP_CANCELLED = 0
wxEVT_STC_AUTOCOMP_CHAR_DELETED = 0
wxEVT_STC_AUTOCOMP_SELECTION = 0
wxEVT_STC_CALLTIP_CLICK = 0
wxEVT_STC_CHANGE = 0
wxEVT_STC_CHARADDED = 0
wxEVT_STC_DOUBLECLICK = 0
wxEVT_STC_DO_DROP = 0
wxEVT_STC_DRAG_OVER = 0
wxEVT_STC_DWELLEND = 0
wxEVT_STC_DWELLSTART = 0
wxEVT_STC_HOTSPOT_CLICK = 0
wxEVT_STC_HOTSPOT_DCLICK = 0
wxEVT_STC_HOTSPOT_RELEASE_CLICK = 0
wxEVT_STC_INDICATOR_CLICK = 0
wxEVT_STC_INDICATOR_RELEASE = 0
wxEVT_STC_KEY = 0
wxEVT_STC_MACRORECORD = 0
wxEVT_STC_MARGINCLICK = 0
wxEVT_STC_MODIFIED = 0
wxEVT_STC_NEEDSHOWN = 0
wxEVT_STC_PAINTED = 0
wxEVT_STC_ROMODIFYATTEMPT = 0
wxEVT_STC_SAVEPOINTLEFT = 0
wxEVT_STC_SAVEPOINTREACHED = 0
wxEVT_STC_START_DRAG = 0
wxEVT_STC_STYLENEEDED = 0
wxEVT_STC_UPDATEUI = 0
wxEVT_STC_URIDROPPED = 0
wxEVT_STC_USERLISTSELECTION = 0
wxEVT_STC_ZOOM = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Date = object
FillDate = dummy_function
FormatDay = dummy_function
FromJulian = dummy_function
Month = dict()
TodayDay = dummy_function
_ = dummy_function
dayOfWeek = dummy_function
day_abbr = []
day_name = []
daysPerMonth = dummy_function
isleap = dummy_function
julianDay = dummy_function
leapdays = dummy_function
mdays = []
now = object



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


_min_adobe_version = None
get_acroversion = dummy_function
get_min_adobe_version = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


GenBitmapButton = object
GenBitmapTextButton = object
GenBitmapTextToggleButton = object
GenBitmapToggleButton = object
GenButton = object
GenButtonEvent = object
GenToggleButton = object
ThemedGenBitmapButton = object
ThemedGenBitmapTextButton = object
ThemedGenBitmapTextToggleButton = object
ThemedGenBitmapToggleButton = object
ThemedGenButton = object
ThemedGenToggleButton = object
__ThemedMixin = object
__ToggleMixin = object



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AUI_BUTTON_CLOSE = object
AUI_BUTTON_CUSTOM1 = object
AUI_BUTTON_CUSTOM2 = object
AUI_BUTTON_CUSTOM3 = object
AUI_BUTTON_DOWN = object
AUI_BUTTON_LEFT = object
AUI_BUTTON_MAXIMIZE_RESTORE = object
AUI_BUTTON_MINIMIZE = object
AUI_BUTTON_OPTIONS = object
AUI_BUTTON_PIN = object
AUI_BUTTON_RIGHT = object
AUI_BUTTON_STATE_CHECKED = object
AUI_BUTTON_STATE_DISABLED = object
AUI_BUTTON_STATE_HIDDEN = object
AUI_BUTTON_STATE_HOVER = object
AUI_BUTTON_STATE_NORMAL = object
AUI_BUTTON_STATE_PRESSED = object
AUI_BUTTON_UP = object
AUI_BUTTON_WINDOWLIST = object
AUI_DOCKART_ACTIVE_CAPTION_COLOUR = object
AUI_DOCKART_ACTIVE_CAPTION_GRADIENT_COLOUR = object
AUI_DOCKART_ACTIVE_CAPTION_TEXT_COLOUR = object
AUI_DOCKART_BACKGROUND_COLOUR = object
AUI_DOCKART_BORDER_COLOUR = object
AUI_DOCKART_CAPTION_FONT = object
AUI_DOCKART_CAPTION_SIZE = object
AUI_DOCKART_GRADIENT_TYPE = object
AUI_DOCKART_GRIPPER_COLOUR = object
AUI_DOCKART_GRIPPER_SIZE = object
AUI_DOCKART_INACTIVE_CAPTION_COLOUR = object
AUI_DOCKART_INACTIVE_CAPTION_GRADIENT_COLOUR = object
AUI_DOCKART_INACTIVE_CAPTION_TEXT_COLOUR = object
AUI_DOCKART_PANE_BORDER_SIZE = object
AUI_DOCKART_PANE_BUTTON_SIZE = object
AUI_DOCKART_SASH_COLOUR = object
AUI_DOCKART_SASH_SIZE = object
AUI_DOCK_BOTTOM = object
AUI_DOCK_CENTER = object
AUI_DOCK_CENTRE = object
AUI_DOCK_LEFT = object
AUI_DOCK_NONE = object
AUI_DOCK_RIGHT = object
AUI_DOCK_TOP = object
AUI_GRADIENT_HORIZONTAL = object
AUI_GRADIENT_NONE = object
AUI_GRADIENT_VERTICAL = object
AUI_MGR_ALLOW_ACTIVE_PANE = object
AUI_MGR_ALLOW_FLOATING = object
AUI_MGR_DEFAULT = object
AUI_MGR_HINT_FADE = object
AUI_MGR_LIVE_RESIZE = object
AUI_MGR_NO_VENETIAN_BLINDS_FADE = object
AUI_MGR_RECTANGLE_HINT = object
AUI_MGR_TRANSPARENT_DRAG = object
AUI_MGR_TRANSPARENT_HINT = object
AUI_MGR_VENETIAN_BLINDS_HINT = object
AUI_NB_BOTTOM = object
AUI_NB_CLOSE_BUTTON = object
AUI_NB_CLOSE_ON_ACTIVE_TAB = object
AUI_NB_CLOSE_ON_ALL_TABS = object
AUI_NB_DEFAULT_STYLE = object
AUI_NB_LEFT = object
AUI_NB_MIDDLE_CLICK_CLOSE = object
AUI_NB_RIGHT = object
AUI_NB_SCROLL_BUTTONS = object
AUI_NB_TAB_EXTERNAL_MOVE = object
AUI_NB_TAB_FIXED_WIDTH = object
AUI_NB_TAB_MOVE = object
AUI_NB_TAB_SPLIT = object
AUI_NB_TOP = object
AUI_NB_WINDOWLIST_BUTTON = object
AUI_ORIENTATION_MASK = object
AUI_TBART_GRIPPER_SIZE = object
AUI_TBART_OVERFLOW_SIZE = object
AUI_TBART_SEPARATOR_SIZE = object
AUI_TBTOOL_TEXT_BOTTOM = object
AUI_TBTOOL_TEXT_LEFT = object
AUI_TBTOOL_TEXT_RIGHT = object
AUI_TBTOOL_TEXT_TOP = object
AUI_TB_DEFAULT_STYLE = object
AUI_TB_GRIPPER = object
AUI_TB_HORIZONTAL = object
AUI_TB_HORZ_LAYOUT = object
AUI_TB_HORZ_TEXT = object
AUI_TB_NO_AUTORESIZE = object
AUI_TB_NO_TOOLTIPS = object
AUI_TB_OVERFLOW = object
AUI_TB_PLAIN_BACKGROUND = object
AUI_TB_TEXT = object
AUI_TB_VERTICAL = object
AuiButtonId = object
AuiDefaultDockArt = object
AuiDefaultTabArt = object
AuiDefaultToolBarArt = object
AuiDockArt = object
AuiDockInfo = object
AuiDockInfoArray = object
AuiDockInfoPtrArray = object
AuiDockUIPart = object
AuiDockUIPartArray = object
AuiMDIChildFrame = object
AuiMDIClientWindow = object
AuiMDIParentFrame = object
AuiManager = object
AuiManagerDock = object
AuiManagerEvent = object
AuiManagerOption = object
AuiNotebook = object
AuiNotebookEvent = object
AuiNotebookOption = object
AuiNotebookPage = object
AuiNotebookPageArray = object
AuiPaneButton = object
AuiPaneButtonArray = object
AuiPaneButtonState = object
AuiPaneDockArtGradients = object
AuiPaneDockArtSetting = object
AuiPaneInfo = object
AuiPaneInfoArray = object
AuiPaneInfoPtrArray = object
AuiSimpleTabArt = object
AuiTabArt = object
AuiTabContainer = object
AuiTabContainerButton = object
AuiTabContainerButtonArray = object
AuiTabCtrl = object
AuiToolBar = object
AuiToolBarArt = object
AuiToolBarArtSetting = object
AuiToolBarEvent = object
AuiToolBarItem = object
AuiToolBarItemArray = object
AuiToolBarStyle = object
AuiToolBarToolTextOrientation = object
EVT_AUINOTEBOOK_ALLOW_DND = object
EVT_AUINOTEBOOK_BEGIN_DRAG = object
EVT_AUINOTEBOOK_BG_DCLICK = object
EVT_AUINOTEBOOK_BUTTON = object
EVT_AUINOTEBOOK_DRAG_DONE = object
EVT_AUINOTEBOOK_DRAG_MOTION = object
EVT_AUINOTEBOOK_END_DRAG = object
EVT_AUINOTEBOOK_PAGE_CHANGED = object
EVT_AUINOTEBOOK_PAGE_CHANGING = object
EVT_AUINOTEBOOK_PAGE_CLOSE = object
EVT_AUINOTEBOOK_PAGE_CLOSED = object
EVT_AUINOTEBOOK_TAB_MIDDLE_DOWN = object
EVT_AUINOTEBOOK_TAB_MIDDLE_UP = object
EVT_AUINOTEBOOK_TAB_RIGHT_DOWN = object
EVT_AUINOTEBOOK_TAB_RIGHT_UP = object
EVT_AUITOOLBAR_BEGIN_DRAG = object
EVT_AUITOOLBAR_MIDDLE_CLICK = object
EVT_AUITOOLBAR_OVERFLOW_CLICK = object
EVT_AUITOOLBAR_RIGHT_CLICK = object
EVT_AUITOOLBAR_TOOL_DROPDOWN = object
EVT_AUI_FIND_MANAGER = object
EVT_AUI_PANE_ACTIVATED = object
EVT_AUI_PANE_BUTTON = object
EVT_AUI_PANE_CLOSE = object
EVT_AUI_PANE_MAXIMIZE = object
EVT_AUI_PANE_RESTORE = object
EVT_AUI_RENDER = object
wxEVT_AUINOTEBOOK_ALLOW_DND = 0
wxEVT_AUINOTEBOOK_BEGIN_DRAG = 0
wxEVT_AUINOTEBOOK_BG_DCLICK = 0
wxEVT_AUINOTEBOOK_BUTTON = 0
wxEVT_AUINOTEBOOK_DRAG_DONE = 0
wxEVT_AUINOTEBOOK_DRAG_MOTION = 0
wxEVT_AUINOTEBOOK_END_DRAG = 0
wxEVT_AUINOTEBOOK_PAGE_CHANGED = 0
wxEVT_AUINOTEBOOK_PAGE_CHANGING = 0
wxEVT_AUINOTEBOOK_PAGE_CLOSE = 0
wxEVT_AUINOTEBOOK_PAGE_CLOSED = 0
wxEVT_AUINOTEBOOK_TAB_MIDDLE_DOWN = 0
wxEVT_AUINOTEBOOK_TAB_MIDDLE_UP = 0
wxEVT_AUINOTEBOOK_TAB_RIGHT_DOWN = 0
wxEVT_AUINOTEBOOK_TAB_RIGHT_UP = 0
wxEVT_AUITOOLBAR_BEGIN_DRAG = 0
wxEVT_AUITOOLBAR_MIDDLE_CLICK = 0
wxEVT_AUITOOLBAR_OVERFLOW_CLICK = 0
wxEVT_AUITOOLBAR_RIGHT_CLICK = 0
wxEVT_AUITOOLBAR_TOOL_DROPDOWN = 0
wxEVT_AUI_FIND_MANAGER = 0
wxEVT_AUI_PANE_ACTIVATED = 0
wxEVT_AUI_PANE_BUTTON = 0
wxEVT_AUI_PANE_CLOSE = 0
wxEVT_AUI_PANE_MAXIMIZE = 0
wxEVT_AUI_PANE_RESTORE = 0
wxEVT_AUI_RENDER = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


CR_SIZE = 0
DrawSash = dummy_function
EmptyChild = object
MV_HOR = 0
MultiClient = object
MultiCloser = object
MultiCreator = object
MultiSash = object
MultiSizer = object
MultiSplit = object
MultiViewLeaf = object
SH_SIZE = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AboutDialog = object
AboutService = object
Blank = object
ChildDocTemplate = object
ChildDocument = object
Copy = object
Cut = object
DocApp = object
DocFrameMixIn = object
DocMDIChildFrame = object
DocMDIParentFrame = object
DocMDIParentFrameMixIn = object
DocOptionsService = object
DocSDIFrame = object
DocService = object
DocTabbedChildFrame = object
DocTabbedParentFrame = object
EMBEDDED_WINDOW_ALL = 0
EMBEDDED_WINDOW_BOTTOM = 0
EMBEDDED_WINDOW_BOTTOMLEFT = 0
EMBEDDED_WINDOW_BOTTOMRIGHT = 0
EMBEDDED_WINDOW_LEFT = 0
EMBEDDED_WINDOW_RIGHT = 0
EMBEDDED_WINDOW_TOP = 0
EMBEDDED_WINDOW_TOPLEFT = 0
EMBEDDED_WINDOW_TOPRIGHT = 0
FilePropertiesDialog = object
FilePropertiesService = object
GeneralOptionsPanel = object
New = object
Open = object
OptionsDialog = object
Paste = object
Print = object
PrintPreview = object
PyEmbeddedImage = object
Redo = object
RowColSizer = object
SAVEALL_ID = object
Save = object
SaveAll = object
Undo = object
VIEW_STATUSBAR_ID = object
VIEW_TOOLBAR_ID = object
WINDOW_MENU_NUM_ITEMS = 0
WindowMenuService = object
_ = dummy_function
_DocFrameFileDropTarget = object
getBlankIcon = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_IP_SELECTION_CHANGED = object
IP_DEFAULT_STYLE = 0
IP_REMOVE_FROM_CHOICES = 0
IP_SORT_CHOICES = 0
IP_SORT_SELECTED = 0
IpSelectionChanged = object
ItemsPicker = object
LB_STYLE = 0
wxEVT_IP_SELECTION_CHANGED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


BAD_IMAGE = 0
BitmapButton = object
ConvertBMP = dummy_function
FindFiles = object
GetCheckeredBitmap = dummy_function
GetNamedBitmap = dummy_function
ID_BLACK_BG = object
ID_BOX_FRAME = object
ID_CHECK_BG = object
ID_CROP_FRAME = object
ID_GREY_BG = object
ID_NO_FRAME = object
ID_WHITE_BG = object
IMG_CATALOG = dict()
ImageDialog = object
ImagePanel = object
ImageView = object
PyEmbeddedImage = object
_ = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


BaseComboTreeBox = object
BasePopupFrame = object
ComboTreeBox = dummy_function
GTKComboTreeBox = object
GTKPopupFrame = object
IterableTreeCtrl = object
MACComboTreeBox = object
MACPopupFrame = object
MSWComboTreeBox = object
MSWPopupFrame = object
NativeComboTreeBox = object



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Command = object
CommandProcessor = object
DEFAULT_DOCMAN_FLAGS = 0
DEFAULT_TEMPLATE_FLAGS = 0
DOC_MDI = 0
DOC_NEW = 0
DOC_NO_VIEW = 0
DOC_OPEN_ONCE = 0
DOC_SDI = 0
DOC_SILENT = 0
DocChildFrame = object
DocMDIChildFrame = object
DocMDIParentFrame = object
DocManager = object
DocParentFrame = object
DocPrintout = object
DocTemplate = object
Document = object
FileExists = dummy_function
FileNameFromPath = dummy_function
FindExtension = dummy_function
MAX_FILE_HISTORY = 0
PathOnly = dummy_function
TEMPLATE_INVISIBLE = 0
TEMPLATE_NO_CREATE = 0
TEMPLATE_VISIBLE = 0
View = object
_ = dummy_function
cmp_to_key = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


DialogResults = object
MultiMessageBox = dummy_function
MultiMessageDialog = object
MultipleChoiceDialog = object
ScrolledMessageDialog = object
alertDialog = dummy_function
colorDialog = dummy_function
colourDialog = dummy_function
dirDialog = dummy_function
directoryDialog = dummy_function
fileDialog = dummy_function
findDialog = dummy_function
fontDialog = dummy_function
messageDialog = dummy_function
multipleChoiceDialog = dummy_function
openFileDialog = dummy_function
returnedString = dummy_function
saveFileDialog = dummy_function
scrolledMessageDialog = dummy_function
singleChoiceDialog = dummy_function
textEntryDialog = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


GetDefaultBorder = dummy_function
GetDefaultPanelBorder = dummy_function
GetDialogBorder = dummy_function
GetHGrow = dummy_function
GetSizerProps = dummy_function
GetVGrow = dummy_function
SetDefaultSizerProps = dummy_function
SetHGrow = dummy_function
SetSizerProp = dummy_function
SetSizerProps = dummy_function
SetVGrow = dummy_function
SizedDialog = object
SizedFrame = object
SizedPanel = object
SizedParent = object
SizedScrolledPanel = object
SizedStaticBox = object
align = dict()
border = dict()
halign = dict()
minsize = dict()
misc_flags = dict()
valign = dict()



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


DCRenderer = object
GetExtent = dummy_function
GetFullExtent = dummy_function
RenderToBitmap = dummy_function
RenderToDC = dummy_function
RenderToRenderer = dummy_function
Renderer = object
SizeRenderer = object
StaticFancyText = object
_addGreek = dummy_function
_families = dict()
_greekEncoding = ''
_greek_letters = tuple()
_styles = dict()
_weights = dict()
getExtent = dummy_function
iceil = dummy_function
iround = dummy_function
renderToBitmap = dummy_function
renderToDC = dummy_function
test = dummy_function



#!/usr/bin/env python
"""Setup script"""

from setuptools import setup, find_packages

description = """
This module does nothing, but is useful when trying to build documentation
for modules that require wxPython.

Do not install this module if you already have wxPython installed, as it uses
the same "wx" package name to pretend to be wxPython.

"""

setup(
    author="Dominic Davis-Foster",
    author_email="dominic@davis-foster.co.uk",
    description="This module does nothing",
    license="LGPLv3+",
    long_description=description,
    name="dummy_wx",
    packages=find_packages(),
    version="0.2.1",
    )



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


PI_HIDEINACTIVE = 0
PI_PULSEMODE = 0
ProgressIndicator = object



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_WEBVIEW_ERROR = object
EVT_WEBVIEW_LOADED = object
EVT_WEBVIEW_NAVIGATED = object
EVT_WEBVIEW_NAVIGATING = object
EVT_WEBVIEW_NEWWINDOW = object
EVT_WEBVIEW_TITLE_CHANGED = object
USE_WEBVIEW = 0
WEBVIEW_FIND_BACKWARDS = object
WEBVIEW_FIND_DEFAULT = object
WEBVIEW_FIND_ENTIRE_WORD = object
WEBVIEW_FIND_HIGHLIGHT_RESULT = object
WEBVIEW_FIND_MATCH_CASE = object
WEBVIEW_FIND_WRAP = object
WEBVIEW_NAV_ERR_AUTH = object
WEBVIEW_NAV_ERR_CERTIFICATE = object
WEBVIEW_NAV_ERR_CONNECTION = object
WEBVIEW_NAV_ERR_NOT_FOUND = object
WEBVIEW_NAV_ERR_OTHER = object
WEBVIEW_NAV_ERR_REQUEST = object
WEBVIEW_NAV_ERR_SECURITY = object
WEBVIEW_NAV_ERR_USER_CANCELLED = object
WEBVIEW_RELOAD_DEFAULT = object
WEBVIEW_RELOAD_NO_CACHE = object
WEBVIEW_ZOOM_LARGE = object
WEBVIEW_ZOOM_LARGEST = object
WEBVIEW_ZOOM_MEDIUM = object
WEBVIEW_ZOOM_SMALL = object
WEBVIEW_ZOOM_TINY = object
WEBVIEW_ZOOM_TYPE_LAYOUT = object
WEBVIEW_ZOOM_TYPE_TEXT = object
WebView = object
WebViewArchiveHandler = object
WebViewBackendDefault = bytes()
WebViewBackendIE = bytes()
WebViewBackendWebKit = bytes()
WebViewDefaultURLStr = bytes()
WebViewEvent = object
WebViewFSHandler = object
WebViewFactory = object
WebViewFindFlags = object
WebViewHandler = object
WebViewHistoryItem = object
WebViewNameStr = bytes()
WebViewNavigationError = object
WebViewReloadFlags = object
WebViewZoom = object
WebViewZoomType = object
wxEVT_COMMAND_WEBVIEW_ERROR = 0
wxEVT_COMMAND_WEBVIEW_LOADED = 0
wxEVT_COMMAND_WEBVIEW_NAVIGATED = 0
wxEVT_COMMAND_WEBVIEW_NAVIGATING = 0
wxEVT_COMMAND_WEBVIEW_NEWWINDOW = 0
wxEVT_COMMAND_WEBVIEW_TITLE_CHANGED = 0
wxEVT_WEBVIEW_ERROR = 0
wxEVT_WEBVIEW_LOADED = 0
wxEVT_WEBVIEW_NAVIGATED = 0
wxEVT_WEBVIEW_NAVIGATING = 0
wxEVT_WEBVIEW_NEWWINDOW = 0
wxEVT_WEBVIEW_TITLE_CHANGED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_RICHTEXT_BUFFER_RESET = object
EVT_RICHTEXT_CHARACTER = object
EVT_RICHTEXT_CONTENT_DELETED = object
EVT_RICHTEXT_CONTENT_INSERTED = object
EVT_RICHTEXT_DELETE = object
EVT_RICHTEXT_FOCUS_OBJECT_CHANGED = object
EVT_RICHTEXT_LEFT_CLICK = object
EVT_RICHTEXT_LEFT_DCLICK = object
EVT_RICHTEXT_MIDDLE_CLICK = object
EVT_RICHTEXT_RETURN = object
EVT_RICHTEXT_RIGHT_CLICK = object
EVT_RICHTEXT_SELECTION_CHANGED = object
EVT_RICHTEXT_STYLESHEET_CHANGED = object
EVT_RICHTEXT_STYLESHEET_CHANGING = object
EVT_RICHTEXT_STYLESHEET_REPLACED = object
EVT_RICHTEXT_STYLESHEET_REPLACING = object
EVT_RICHTEXT_STYLE_CHANGED = object
ID_RICHTEXT_PROPERTIES1 = 0
ID_RICHTEXT_PROPERTIES2 = 0
ID_RICHTEXT_PROPERTIES3 = 0
RE_CENTER_CARET = 0
RE_CENTRE_CARET = 0
RE_MULTILINE = 0
RE_READONLY = 0
RICHTEXT_ALL = object
RICHTEXT_ALT_DOWN = 0
RICHTEXT_CACHE_SIZE = 0
RICHTEXT_CHANGE_ATTRIBUTES = object
RICHTEXT_CHANGE_OBJECT = object
RICHTEXT_CHANGE_STYLE = object
RICHTEXT_CTRL_DOWN = 0
RICHTEXT_DELETE = object
RICHTEXT_DRAW_GUIDELINES = 0
RICHTEXT_DRAW_IGNORE_CACHE = 0
RICHTEXT_DRAW_PRINT = 0
RICHTEXT_DRAW_SELECTED = 0
RICHTEXT_EX_NO_GUIDELINES = 0
RICHTEXT_FIXED_HEIGHT = 0
RICHTEXT_FIXED_WIDTH = 0
RICHTEXT_FORMATTED = 0
RICHTEXT_FORMAT_BULLETS = 0
RICHTEXT_FORMAT_FONT = 0
RICHTEXT_FORMAT_INDENTS_SPACING = 0
RICHTEXT_FORMAT_STYLE_EDITOR = 0
RICHTEXT_FORMAT_TABS = 0
RICHTEXT_HANDLER_CONVERT_FACENAMES = 0
RICHTEXT_HANDLER_INCLUDE_STYLESHEET = 0
RICHTEXT_HANDLER_NO_HEADER_FOOTER = 0
RICHTEXT_HANDLER_SAVE_IMAGES_TO_BASE64 = 0
RICHTEXT_HANDLER_SAVE_IMAGES_TO_FILES = 0
RICHTEXT_HANDLER_SAVE_IMAGES_TO_MEMORY = 0
RICHTEXT_HEIGHT_ONLY = 0
RICHTEXT_HITTEST_AFTER = object
RICHTEXT_HITTEST_BEFORE = object
RICHTEXT_HITTEST_HONOUR_ATOMIC = object
RICHTEXT_HITTEST_NONE = object
RICHTEXT_HITTEST_NO_FLOATING_OBJECTS = object
RICHTEXT_HITTEST_NO_NESTED_OBJECTS = object
RICHTEXT_HITTEST_ON = object
RICHTEXT_HITTEST_OUTSIDE = object
RICHTEXT_INSERT = object
RICHTEXT_INSERT_INTERACTIVE = 0
RICHTEXT_INSERT_NONE = 0
RICHTEXT_INSERT_WITH_PREVIOUS_PARAGRAPH_STYLE = 0
RICHTEXT_LAYOUT_SPECIFIED_RECT = 0
RICHTEXT_NONE = object
RICHTEXT_NO_SELECTION = object
RICHTEXT_ORGANISER_APPLY_STYLES = 0
RICHTEXT_ORGANISER_BROWSE = 0
RICHTEXT_ORGANISER_BROWSE_NUMBERING = 0
RICHTEXT_ORGANISER_CREATE_STYLES = 0
RICHTEXT_ORGANISER_DELETE_STYLES = 0
RICHTEXT_ORGANISER_EDIT_STYLES = 0
RICHTEXT_ORGANISER_OK_CANCEL = 0
RICHTEXT_ORGANISER_ORGANISE = 0
RICHTEXT_ORGANISER_RENAME_STYLES = 0
RICHTEXT_ORGANISER_RENUMBER = 0
RICHTEXT_ORGANISER_SHOW_ALL = 0
RICHTEXT_ORGANISER_SHOW_BOX = 0
RICHTEXT_ORGANISER_SHOW_CHARACTER = 0
RICHTEXT_ORGANISER_SHOW_LIST = 0
RICHTEXT_ORGANISER_SHOW_PARAGRAPH = 0
RICHTEXT_PAGE_ALL = object
RICHTEXT_PAGE_CENTRE = object
RICHTEXT_PAGE_EVEN = object
RICHTEXT_PAGE_LEFT = object
RICHTEXT_PAGE_ODD = object
RICHTEXT_PAGE_RIGHT = object
RICHTEXT_SETPROPERTIES_CHARACTERS_ONLY = 0
RICHTEXT_SETPROPERTIES_NONE = 0
RICHTEXT_SETPROPERTIES_PARAGRAPHS_ONLY = 0
RICHTEXT_SETPROPERTIES_REMOVE = 0
RICHTEXT_SETPROPERTIES_RESET = 0
RICHTEXT_SETPROPERTIES_WITH_UNDO = 0
RICHTEXT_SETSTYLE_CHARACTERS_ONLY = 0
RICHTEXT_SETSTYLE_NONE = 0
RICHTEXT_SETSTYLE_OPTIMIZE = 0
RICHTEXT_SETSTYLE_PARAGRAPHS_ONLY = 0
RICHTEXT_SETSTYLE_REMOVE = 0
RICHTEXT_SETSTYLE_RENUMBER = 0
RICHTEXT_SETSTYLE_RESET = 0
RICHTEXT_SETSTYLE_SPECIFY_LEVEL = 0
RICHTEXT_SETSTYLE_WITH_UNDO = 0
RICHTEXT_SHIFT_DOWN = 0
RICHTEXT_TYPE_ANY = object
RICHTEXT_TYPE_HTML = object
RICHTEXT_TYPE_PDF = object
RICHTEXT_TYPE_RTF = object
RICHTEXT_TYPE_TEXT = object
RICHTEXT_TYPE_XML = object
RICHTEXT_UNFORMATTED = 0
RICHTEXT_VARIABLE_HEIGHT = 0
RICHTEXT_VARIABLE_WIDTH = 0
RichTextAction = object
RichTextActionList = object
RichTextActionList_iterator = object
RichTextApplyStyle = dummy_function
RichTextAttr = object
RichTextAttrArray = object
RichTextBitlistsEqPartial = dummy_function
RichTextBox = object
RichTextBuffer = object
RichTextBufferDataObject = object
RichTextCell = object
RichTextCharacterStyleDefinition = object
RichTextCombineBitlists = dummy_function
RichTextCommand = object
RichTextCommandId = object
RichTextCompositeObject = object
RichTextContextMenuPropertiesInfo = object
RichTextCtrl = object
RichTextCtrlSelectionState = object
RichTextCtrlSelectionState_CommonAncestor = object
RichTextCtrlSelectionState_Normal = object
RichTextDecimalToRoman = dummy_function
RichTextDrawingContext = object
RichTextDrawingHandler = object
RichTextDrawingHandlerList = object
RichTextDrawingHandlerList_iterator = object
RichTextEvent = object
RichTextField = object
RichTextFieldType = object
RichTextFieldTypeStandard = object
RichTextFileHandler = object
RichTextFileHandlerList = object
RichTextFileHandlerList_iterator = object
RichTextFileType = object
RichTextFloatCollector = object
RichTextFontTable = object
RichTextFormattingDialog = object
RichTextFormattingDialogFactory = object
RichTextHTMLHandler = object
RichTextHasStyle = dummy_function
RichTextHeaderFooterData = object
RichTextHitTestFlags = object
RichTextImage = object
RichTextImageBlock = object
RichTextLine = object
RichTextLineBreakChar = ''
RichTextLineList = object
RichTextLineList_iterator = object
RichTextListStyleDefinition = object
RichTextModuleInit = dummy_function
RichTextObject = object
RichTextObjectAddress = object
RichTextObjectList = object
RichTextObjectList_ = object
RichTextObjectList__iterator = object
RichTextObjectList_iterator = object
RichTextObjectPtrArray = object
RichTextObjectPtrArrayArray = object
RichTextOddEvenPage = object
RichTextPageLocation = object
RichTextParagraph = object
RichTextParagraphLayoutBox = object
RichTextParagraphStyleDefinition = object
RichTextPlainText = object
RichTextPlainTextHandler = object
RichTextPrinting = object
RichTextPrintout = object
RichTextProperties = object
RichTextRange = object
RichTextRangeArray = object
RichTextRemoveStyle = dummy_function
RichTextRenderer = object
RichTextSelection = object
RichTextSplitParaCharStyles = dummy_function
RichTextStdRenderer = object
RichTextStyleComboCtrl = object
RichTextStyleDefinition = object
RichTextStyleListBox = object
RichTextStyleListCtrl = object
RichTextStyleOrganiserDialog = object
RichTextStyleSheet = object
RichTextTable = object
RichTextTabsEq = dummy_function
RichTextVariantArray = object
RichTextXMLHandler = object
SCRIPT_MUL_FACTOR = 0.0
SymbolPickerDialog = object
TEXT_ATTR_KEEP_FIRST_PARA_STYLE = 0
TEXT_ATTR_UNITS_HUNDREDTHS_POINT = object
TEXT_ATTR_UNITS_MASK = object
TEXT_ATTR_UNITS_PERCENTAGE = object
TEXT_ATTR_UNITS_PIXELS = object
TEXT_ATTR_UNITS_POINTS = object
TEXT_ATTR_UNITS_TENTHS_MM = object
TEXT_ATTR_VALUE_VALID = object
TEXT_ATTR_VALUE_VALID_MASK = object
TEXT_BOX_ATTR_BORDER_COLOUR = object
TEXT_BOX_ATTR_BORDER_DASHED = object
TEXT_BOX_ATTR_BORDER_DOTTED = object
TEXT_BOX_ATTR_BORDER_DOUBLE = object
TEXT_BOX_ATTR_BORDER_GROOVE = object
TEXT_BOX_ATTR_BORDER_INSET = object
TEXT_BOX_ATTR_BORDER_MEDIUM = object
TEXT_BOX_ATTR_BORDER_NONE = object
TEXT_BOX_ATTR_BORDER_OUTSET = object
TEXT_BOX_ATTR_BORDER_RIDGE = object
TEXT_BOX_ATTR_BORDER_SOLID = object
TEXT_BOX_ATTR_BORDER_STYLE = object
TEXT_BOX_ATTR_BORDER_THICK = object
TEXT_BOX_ATTR_BORDER_THIN = object
TEXT_BOX_ATTR_CLEAR = object
TEXT_BOX_ATTR_CLEAR_BOTH = object
TEXT_BOX_ATTR_CLEAR_LEFT = object
TEXT_BOX_ATTR_CLEAR_NONE = object
TEXT_BOX_ATTR_CLEAR_RIGHT = object
TEXT_BOX_ATTR_COLLAPSE_BORDERS = object
TEXT_BOX_ATTR_COLLAPSE_FULL = object
TEXT_BOX_ATTR_COLLAPSE_NONE = object
TEXT_BOX_ATTR_FLOAT = object
TEXT_BOX_ATTR_FLOAT_LEFT = object
TEXT_BOX_ATTR_FLOAT_NONE = object
TEXT_BOX_ATTR_FLOAT_RIGHT = object
TEXT_BOX_ATTR_POSITION_ABSOLUTE = object
TEXT_BOX_ATTR_POSITION_FIXED = object
TEXT_BOX_ATTR_POSITION_MASK = object
TEXT_BOX_ATTR_POSITION_RELATIVE = object
TEXT_BOX_ATTR_POSITION_STATIC = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT_BOTTOM = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT_CENTRE = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT_NONE = object
TEXT_BOX_ATTR_VERTICAL_ALIGNMENT_TOP = object
TextAttrBorder = object
TextAttrBorderFlags = object
TextAttrBorderStyle = object
TextAttrBorderWidth = object
TextAttrBorders = object
TextAttrCollectCommonAttributes = dummy_function
TextAttrDimension = object
TextAttrDimensionConverter = object
TextAttrDimensions = object
TextAttrEq = dummy_function
TextAttrSize = object
TextAttrUnits = object
TextAttrValueFlags = object
TextBoxAttr = object
TextBoxAttrClearStyle = object
TextBoxAttrCollapseMode = object
TextBoxAttrFlags = object
TextBoxAttrFloatStyle = object
TextBoxAttrPosition = object
TextBoxAttrVerticalAlignment = object
_im_RichTextRange = object
wxEVT_RICHTEXT_BUFFER_RESET = 0
wxEVT_RICHTEXT_CHARACTER = 0
wxEVT_RICHTEXT_CONSUMING_CHARACTER = 0
wxEVT_RICHTEXT_CONTENT_DELETED = 0
wxEVT_RICHTEXT_CONTENT_INSERTED = 0
wxEVT_RICHTEXT_DELETE = 0
wxEVT_RICHTEXT_FOCUS_OBJECT_CHANGED = 0
wxEVT_RICHTEXT_LEFT_CLICK = 0
wxEVT_RICHTEXT_LEFT_DCLICK = 0
wxEVT_RICHTEXT_MIDDLE_CLICK = 0
wxEVT_RICHTEXT_PROPERTIES_CHANGED = 0
wxEVT_RICHTEXT_RETURN = 0
wxEVT_RICHTEXT_RIGHT_CLICK = 0
wxEVT_RICHTEXT_SELECTION_CHANGED = 0
wxEVT_RICHTEXT_STYLESHEET_CHANGED = 0
wxEVT_RICHTEXT_STYLESHEET_CHANGING = 0
wxEVT_RICHTEXT_STYLESHEET_REPLACED = 0
wxEVT_RICHTEXT_STYLESHEET_REPLACING = 0
wxEVT_RICHTEXT_STYLE_CHANGED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AC_DEFAULT_STYLE = 0
AC_NO_AUTORESIZE = 0
ANIMATION_TYPE_ANI = object
ANIMATION_TYPE_ANY = object
ANIMATION_TYPE_GIF = object
ANIMATION_TYPE_INVALID = object
AboutBox = dummy_function
AboutDialogInfo = object
Animation = object
AnimationCtrl = object
AnimationCtrlNameStr = bytes()
AnimationType = object
BannerWindow = object
BannerWindowNameStr = bytes()
BitmapComboBox = object
BitmapComboBoxNameStr = bytes()
CAL_BORDER_NONE = object
CAL_BORDER_ROUND = object
CAL_BORDER_SQUARE = object
CAL_HITTEST_DAY = object
CAL_HITTEST_DECMONTH = object
CAL_HITTEST_HEADER = object
CAL_HITTEST_INCMONTH = object
CAL_HITTEST_NOWHERE = object
CAL_HITTEST_SURROUNDING_WEEK = object
CAL_HITTEST_WEEK = object
CAL_MONDAY_FIRST = 0
CAL_NO_MONTH_CHANGE = 0
CAL_NO_YEAR_CHANGE = 0
CAL_SEQUENTIAL_MONTH_SELECTION = 0
CAL_SHOW_HOLIDAYS = 0
CAL_SHOW_SURROUNDING_WEEKS = 0
CAL_SHOW_WEEK_NUMBERS = 0
CAL_SUNDAY_FIRST = 0
CalculateLayoutEvent = object
CalendarCtrl = object
CalendarDateAttr = object
CalendarDateBorder = object
CalendarEvent = object
CalendarHitTestResult = object
CalendarNameStr = bytes()
CommandLinkButton = object
CreateFileTipProvider = dummy_function
DP_ALLOWNONE = 0
DP_DEFAULT = 0
DP_DROPDOWN = 0
DP_SHOWCENTURY = 0
DP_SPIN = 0
DateEvent = object
DatePickerCtrl = object
EL_ALLOW_DELETE = 0
EL_ALLOW_EDIT = 0
EL_ALLOW_NEW = 0
EL_DEFAULT_STYLE = 0
EL_NO_REORDER = 0
EVT_CALCULATE_LAYOUT = object
EVT_CALENDAR = object
EVT_CALENDAR_DAY = object
EVT_CALENDAR_MONTH = object
EVT_CALENDAR_PAGE_CHANGED = object
EVT_CALENDAR_SEL_CHANGED = object
EVT_CALENDAR_WEEKDAY_CLICKED = object
EVT_CALENDAR_WEEK_CLICKED = object
EVT_CALENDAR_YEAR = object
EVT_DATE_CHANGED = object
EVT_HYPERLINK = object
EVT_QUERY_LAYOUT_INFO = object
EVT_SASH_DRAGGED = object
EVT_SASH_DRAGGED_RANGE = object
EVT_TASKBAR_BALLOON_CLICK = object
EVT_TASKBAR_BALLOON_TIMEOUT = object
EVT_TASKBAR_CLICK = object
EVT_TASKBAR_LEFT_DCLICK = object
EVT_TASKBAR_LEFT_DOWN = object
EVT_TASKBAR_LEFT_UP = object
EVT_TASKBAR_MOVE = object
EVT_TASKBAR_RIGHT_DCLICK = object
EVT_TASKBAR_RIGHT_DOWN = object
EVT_TASKBAR_RIGHT_UP = object
EVT_TIME_CHANGED = object
EVT_WIZARD_BEFORE_PAGE_CHANGED = object
EVT_WIZARD_CANCEL = object
EVT_WIZARD_FINISHED = object
EVT_WIZARD_HELP = object
EVT_WIZARD_PAGE_CHANGED = object
EVT_WIZARD_PAGE_CHANGING = object
EVT_WIZARD_PAGE_SHOWN = object
EditableListBox = object
EditableListBoxNameStr = bytes()
ExtHelpController = object
GenericAboutBox = dummy_function
GenericCalendarCtrl = object
GenericDatePickerCtrl = object
HL_ALIGN_CENTRE = 0
HL_ALIGN_LEFT = 0
HL_ALIGN_RIGHT = 0
HL_CONTEXTMENU = 0
HL_DEFAULT_STYLE = 0
HyperlinkCtrl = object
HyperlinkCtrlNameStr = bytes()
HyperlinkEvent = object
Joystick = object
LAYOUT_BOTTOM = object
LAYOUT_HORIZONTAL = object
LAYOUT_LEFT = object
LAYOUT_NONE = object
LAYOUT_RIGHT = object
LAYOUT_TOP = object
LAYOUT_VERTICAL = object
LayoutAlgorithm = object
LayoutAlignment = object
LayoutOrientation = object
NotificationMessage = object
NullAnimation = object
ODCB_DCLICK_CYCLES = 0
ODCB_PAINTING_CONTROL = object
ODCB_PAINTING_SELECTED = object
ODCB_STD_CONTROL_PAINT = 0
OwnerDrawnComboBox = object
OwnerDrawnComboBoxPaintingFlags = object
PROPSHEET_BUTTONTOOLBOOK = object
PROPSHEET_CHOICEBOOK = object
PROPSHEET_DEFAULT = object
PROPSHEET_LISTBOOK = object
PROPSHEET_NOTEBOOK = object
PROPSHEET_SHRINKTOFIT = object
PROPSHEET_TOOLBOOK = object
PROPSHEET_TREEBOOK = object
PropertySheetDialog = object
PropertySheetDialogFlags = object
PseudoDC = object
PyWizardPage = object
QueryLayoutInfoEvent = object
RichToolTip = object
SASH_BOTTOM = object
SASH_LEFT = object
SASH_NONE = object
SASH_RIGHT = object
SASH_STATUS_OK = object
SASH_STATUS_OUT_OF_RANGE = object
SASH_TOP = object
SOUND_ASYNC = 0
SOUND_LOOP = 0
SOUND_SYNC = 0
SPLASH_CENTER_ON_PARENT = 0
SPLASH_CENTER_ON_SCREEN = 0
SPLASH_CENTRE_ON_PARENT = 0
SPLASH_CENTRE_ON_SCREEN = 0
SPLASH_NO_CENTER = 0
SPLASH_NO_CENTRE = 0
SPLASH_NO_TIMEOUT = 0
SPLASH_TIMEOUT = 0
SW_3D = 0
SW_3DBORDER = 0
SW_3DSASH = 0
SW_BORDER = 0
SW_NOBORDER = 0
SashDragStatus = object
SashEdgePosition = object
SashEvent = object
SashLayoutWindow = object
SashWindow = object
ShowTip = dummy_function
Sound = object
SplashScreen = object
TBI_CUSTOM_STATUSITEM = object
TBI_DEFAULT_TYPE = object
TBI_DOCK = object
TP_DEFAULT = 0
TaskBarIcon = object
TaskBarIconEvent = object
TaskBarIconType = object
TimePickerCtrl = object
TipKind = object
TipKind_Auto = object
TipKind_Bottom = object
TipKind_BottomLeft = object
TipKind_BottomRight = object
TipKind_None = object
TipKind_Top = object
TipKind_TopLeft = object
TipKind_TopRight = object
TipProvider = object
USE_JOYSTICK = 0
WIZARD_EX_HELPBUTTON = 0
WIZARD_HALIGN_CENTRE = 0
WIZARD_HALIGN_LEFT = 0
WIZARD_HALIGN_RIGHT = 0
WIZARD_TILE = 0
WIZARD_VALIGN_BOTTOM = 0
WIZARD_VALIGN_CENTRE = 0
WIZARD_VALIGN_TOP = 0
Wizard = object
WizardEvent = object
WizardPage = object
WizardPageSimple = object
wxEVT_CALCULATE_LAYOUT = 0
wxEVT_CALENDAR_DAY_CHANGED = 0
wxEVT_CALENDAR_DOUBLECLICKED = 0
wxEVT_CALENDAR_MONTH_CHANGED = 0
wxEVT_CALENDAR_PAGE_CHANGED = 0
wxEVT_CALENDAR_SEL_CHANGED = 0
wxEVT_CALENDAR_WEEKDAY_CLICKED = 0
wxEVT_CALENDAR_WEEK_CLICKED = 0
wxEVT_CALENDAR_YEAR_CHANGED = 0
wxEVT_COMMAND_HYPERLINK = 0
wxEVT_DATE_CHANGED = 0
wxEVT_HYPERLINK = 0
wxEVT_QUERY_LAYOUT_INFO = 0
wxEVT_SASH_DRAGGED = 0
wxEVT_TASKBAR_BALLOON_CLICK = 0
wxEVT_TASKBAR_BALLOON_TIMEOUT = 0
wxEVT_TASKBAR_CLICK = 0
wxEVT_TASKBAR_LEFT_DCLICK = 0
wxEVT_TASKBAR_LEFT_DOWN = 0
wxEVT_TASKBAR_LEFT_UP = 0
wxEVT_TASKBAR_MOVE = 0
wxEVT_TASKBAR_RIGHT_DCLICK = 0
wxEVT_TASKBAR_RIGHT_DOWN = 0
wxEVT_TASKBAR_RIGHT_UP = 0
wxEVT_TIME_CHANGED = 0
wxEVT_WIZARD_BEFORE_PAGE_CHANGED = 0
wxEVT_WIZARD_CANCEL = 0
wxEVT_WIZARD_FINISHED = 0
wxEVT_WIZARD_HELP = 0
wxEVT_WIZARD_PAGE_CHANGED = 0
wxEVT_WIZARD_PAGE_CHANGING = 0
wxEVT_WIZARD_PAGE_SHOWN = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


PARAMTAG = ''
WXPTAG = ''
_Context = object
_my_import = dummy_function
_param2dict = dummy_function
wxpTagHandler = object
